@@ -38,7 +38,6 @@
 
 ActionRequest::ActionRequest(std::shared_ptr<Context> context, UpnpActionRequest* upnp_request)
     : upnp_request(upnp_request)
-    , errCode(UPNP_E_SUCCESS)
     , actionName(UpnpActionRequest_get_ActionName_cstr(upnp_request))
     , UDN(UpnpActionRequest_get_DevUDN_cstr(upnp_request))
     , serviceID(UpnpActionRequest_get_ServiceID_cstr(upnp_request))
@@ -97,7 +96,7 @@ void ActionRequest::setErrorCode(int errCode)
 
 void ActionRequest::update()
 {
-    if (response != nullptr) {
+    if (response) {
         std::ostringstream buf;
         response->print(buf, "", 0);
         std::string xml = buf.str();
