@@ -39,18 +39,6 @@
 static constexpr bool IS_CDS_ITEM(unsigned int type) { return type & OBJECT_TYPE_ITEM; }
 static constexpr bool IS_CDS_PURE_ITEM(unsigned int type) { return type == OBJECT_TYPE_ITEM; }
 
-CdsObject::CdsObject()
-    : id(INVALID_OBJECT_ID)
-    , refID(INVALID_OBJECT_ID)
-    , parentID(INVALID_OBJECT_ID)
-    , mtime(0)
-    , sizeOnDisk(0)
-    , virt(false)
-    , objectFlags(OBJECT_FLAG_RESTRICTED)
-    , sortPriority(0)
-{
-}
-
 void CdsObject::copyTo(const std::shared_ptr<CdsObject>& obj)
 {
     obj->setID(id);
@@ -69,7 +57,7 @@ void CdsObject::copyTo(const std::shared_ptr<CdsObject>& obj)
     for (auto&& resource : resources)
         obj->addResource(resource->clone());
 }
-bool CdsObject::equals(const std::shared_ptr<CdsObject>& obj, bool exactly)
+bool CdsObject::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) const
 {
     if (!(id == obj->getID()
             && parentID == obj->getParentID()
@@ -94,7 +82,7 @@ bool CdsObject::equals(const std::shared_ptr<CdsObject>& obj, bool exactly)
             && objectFlags == obj->getFlags()));
 }
 
-bool CdsObject::resourcesEqual(const std::shared_ptr<CdsObject>& obj)
+bool CdsObject::resourcesEqual(const std::shared_ptr<CdsObject>& obj) const
 {
     if (resources.size() != obj->resources.size())
         return false;
@@ -104,7 +92,7 @@ bool CdsObject::resourcesEqual(const std::shared_ptr<CdsObject>& obj)
         [](auto&& r1, auto&& r2) { return r1->equals(r2); });
 }
 
-void CdsObject::validate()
+void CdsObject::validate() const
 {
     if (this->title.empty())
         throw_std_runtime_error("Object validation failed: missing title");
@@ -133,11 +121,6 @@ std::shared_ptr<CdsObject> CdsObject::createObject(unsigned int objectType)
 /* CdsItem */
 
 CdsItem::CdsItem()
-    : CdsObject()
-    , mimeType(MIMETYPE_DEFAULT)
-    , partNumber(0)
-    , trackNumber(0)
-    , bookMarkPos(0)
 {
     objectType = OBJECT_TYPE_ITEM;
     upnpClass = "object.item";
@@ -156,7 +139,7 @@ void CdsItem::copyTo(const std::shared_ptr<CdsObject>& obj)
     item->setServiceID(serviceID);
     item->setBookMarkPos(bookMarkPos);
 }
-bool CdsItem::equals(const std::shared_ptr<CdsObject>& obj, bool exactly)
+bool CdsItem::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) const
 {
     auto item = std::static_pointer_cast<CdsItem>(obj);
     if (!CdsObject::equals(obj, exactly))
@@ -164,7 +147,7 @@ bool CdsItem::equals(const std::shared_ptr<CdsObject>& obj, bool exactly)
     return (mimeType == item->getMimeType() && partNumber == item->getPartNumber() && trackNumber == item->getTrackNumber() && serviceID == item->getServiceID() && bookMarkPos == item->getBookMarkPos());
 }
 
-void CdsItem::validate()
+void CdsItem::validate() const
 {
     CdsObject::validate();
     //    log_info("mime: [{}] loc [{}]", this->mimeType.c_str(), this->location.c_str());
@@ -190,10 +173,9 @@ CdsItemExternalURL::CdsItemExternalURL()
     objectType |= OBJECT_TYPE_ITEM_EXTERNAL_URL;
 
     upnpClass = UPNP_CLASS_ITEM;
-    mimeType = MIMETYPE_DEFAULT;
 }
 
-void CdsItemExternalURL::validate()
+void CdsItemExternalURL::validate() const
 {
     CdsItem::validate();
     if (this->mimeType.empty())
@@ -205,11 +187,6 @@ void CdsItemExternalURL::validate()
 //---------
 
 CdsContainer::CdsContainer()
-    : CdsObject()
-    , updateID(0)
-    // searchable = 0; is now in objectFlags; by default all flags (except "restricted") are not set
-    , childCount(-1)
-    , autoscanType(OBJECT_AUTOSCAN_NONE)
 {
     objectType = OBJECT_TYPE_CONTAINER;
     upnpClass = UPNP_CLASS_CONTAINER;
@@ -223,13 +200,13 @@ void CdsContainer::copyTo(const std::shared_ptr<CdsObject>& obj)
     auto cont = std::static_pointer_cast<CdsContainer>(obj);
     cont->setUpdateID(updateID);
 }
-bool CdsContainer::equals(const std::shared_ptr<CdsObject>& obj, bool exactly)
+bool CdsContainer::equals(const std::shared_ptr<CdsObject>& obj, bool exactly) const
 {
     auto cont = std::static_pointer_cast<CdsContainer>(obj);
     return CdsObject::equals(obj, exactly) && isSearchable() == cont->isSearchable();
 }
 
-void CdsContainer::validate()
+void CdsContainer::validate() const
 {
     CdsObject::validate();
     /// \todo well.. we have to know if a container is a real directory or just a virtual container in the database
