@@ -73,7 +73,7 @@ public:
     std::vector<std::shared_ptr<DirectoryTweak>> getArrayCopy();
 
 protected:
-    size_t origSize;
+    size_t origSize {};
     std::map<size_t, std::shared_ptr<DirectoryTweak>> indexMap;
 
     std::recursive_mutex mutex;
@@ -83,10 +83,15 @@ protected:
     void _add(const std::shared_ptr<DirectoryTweak>& dir, size_t index);
 };
 
+#define SETTING_FANART "FanArt"
+#define SETTING_CONTAINERART "ContainerArt"
+#define SETTING_SUBTITLE "SubTitle"
+#define SETTING_RESOURCE "Resource"
+
 /// \brief Provides information about one directory.
 class DirectoryTweak {
 public:
-    explicit DirectoryTweak() = default;
+    DirectoryTweak() = default;
     explicit DirectoryTweak(fs::path location, bool inherit)
         : location(std::move(location))
         , inherit(inherit)
@@ -122,21 +127,24 @@ public:
     bool hasMetaCharset() const { return resourceFiles.find("MetaCharset") != resourceFiles.end(); }
     std::string getMetaCharset() const { return resourceFiles.at("MetaCharset"); }
 
-    void setFanArtFile(const std::string& fanArtFile) { this->resourceFiles["FanArt"] = fanArtFile; }
-    bool hasFanArtFile() const { return resourceFiles.find("FanArt") != resourceFiles.end(); }
-    std::string getFanArtFile() const { return resourceFiles.at("FanArt"); }
+    void setFanArtFile(const std::string& fanArtFile) { this->resourceFiles[SETTING_FANART] = fanArtFile; }
+    bool hasFanArtFile() const { return resourceFiles.find(SETTING_FANART) != resourceFiles.end(); }
+    std::string getFanArtFile() const { return resourceFiles.at(SETTING_FANART); }
 
-    void setSubTitleFile(const std::string& subTitleFile) { this->resourceFiles["SubTitle"] = subTitleFile; }
-    bool hasSubTitleFile() const { return resourceFiles.find("SubTitle") != resourceFiles.end(); }
-    std::string getSubTitleFile() const { return resourceFiles.at("SubTitle"); }
+    void setSubTitleFile(const std::string& subTitleFile) { this->resourceFiles[SETTING_SUBTITLE] = subTitleFile; }
+    bool hasSubTitleFile() const { return resourceFiles.find(SETTING_SUBTITLE) != resourceFiles.end(); }
+    std::string getSubTitleFile() const { return resourceFiles.at(SETTING_SUBTITLE); }
 
-    void setResourceFile(const std::string& resourceFile) { this->resourceFiles["Resource"] = resourceFile; }
-    bool hasResourceFile() const { return resourceFiles.find("Resource") != resourceFiles.end(); }
-    std::string getResourceFile() const { return resourceFiles.at("Resource"); }
+    void setResourceFile(const std::string& resourceFile) { this->resourceFiles[SETTING_RESOURCE] = resourceFile; }
+    bool hasResourceFile() const { return resourceFiles.find(SETTING_RESOURCE) != resourceFiles.end(); }
+    std::string getResourceFile() const { return resourceFiles.at(SETTING_RESOURCE); }
+
+    bool hasSetting(const std::string& setting) const { return resourceFiles.find(setting) != resourceFiles.end(); }
+    std::string getSetting(const std::string& setting) const { return resourceFiles.at(setting); }
 
 protected:
     fs::path location;
-    bool isOrig { false };
+    bool isOrig {};
     bool inherit { true };
     std::map<std::string, std::string> resourceFiles;
     std::map<std::string, bool> flags;
