@@ -45,9 +45,9 @@ class ContentManager;
 class Layout {
 public:
     explicit Layout(std::shared_ptr<ContentManager> content);
-
     virtual ~Layout() = default;
-    virtual void processCdsObject(std::shared_ptr<CdsObject> obj, fs::path rootpath) = 0;
+
+    virtual void processCdsObject(const std::shared_ptr<CdsObject>& obj, fs::path rootpath) = 0;
 
 protected:
     std::shared_ptr<Config> config;
