@@ -33,17 +33,11 @@
 #include "atrailers_content_handler.h" // API
 
 #include "cds_objects.h"
-#include "config/config_manager.h"
+#include "config/config.h"
 #include "metadata/metadata_handler.h"
-#include "online_service.h"
 #include "util/tools.h"
 
-ATrailersContentHandler::ATrailersContentHandler(const std::shared_ptr<Context>& context)
-    : CurlContentHandler(context)
-{
-}
-
-void ATrailersContentHandler::setServiceContent(std::unique_ptr<pugi::xml_document>& service)
+void ATrailersContentHandler::setServiceContent(std::unique_ptr<pugi::xml_document> service)
 {
     service_xml = std::move(service);
     auto root = service_xml->document_element();
@@ -65,7 +59,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getNextObject()
         auto trailer = *trailer_it;
         ++trailer_it;
 
-        if (trailer == nullptr)
+        if (!trailer)
             return nullptr;
 
         if (trailer.type() != pugi::node_element)
@@ -76,9 +70,8 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getNextObject()
 
         // we know that we have a trailer
         auto item = getObject(trailer);
-        if (item != nullptr)
+        if (item)
             return item;
-
     } // while trailer_it
 
     return nullptr;
@@ -91,7 +84,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     item->addResource(resource);
 
     auto info = trailer.child("info");
-    if (info == nullptr)
+    if (!info)
         return nullptr;
 
     std::string temp = info.child("title").text().as_string();
@@ -117,7 +110,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     item->setServiceID(temp);
 
     auto preview = trailer.child("preview");
-    if (preview == nullptr) {
+    if (!preview) {
         log_warning("Failed to retrieve Trailer location for \"{}\", "
                     "skipping...\n",
             item->getTitle().c_str());
@@ -163,7 +156,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     }
 
     auto cast = trailer.child("cast");
-    if (cast != nullptr) {
+    if (cast) {
         std::string actors;
         for (auto&& actor : cast.children()) {
             if (actor.type() != pugi::node_element)
@@ -185,7 +178,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     }
 
     auto genre = trailer.child("genre");
-    if (genre != nullptr) {
+    if (genre) {
         std::string genres;
         for (auto&& gn : genre.children()) {
             if (gn.type() != pugi::node_element)
@@ -212,7 +205,7 @@ std::shared_ptr<CdsObject> ATrailersContentHandler::getObject(const pugi::xml_no
     I add the fastscaler
 
     auto poster = trailer.child("poster");
-    if (poster != nullptr)
+    if (poster)
     {
     }
     */
