@@ -35,10 +35,6 @@
 #ifndef __ATRAILERS_CONTENT_HANDLER_H__
 #define __ATRAILERS_CONTENT_HANDLER_H__
 
-#include <memory>
-#include <pugixml.hpp>
-
-#include "context.h"
 #include "curl_online_service.h"
 
 // forward declaration
@@ -53,11 +49,14 @@ class CdsObject;
 /// metadata XML.
 class ATrailersContentHandler : public CurlContentHandler {
 public:
-    explicit ATrailersContentHandler(const std::shared_ptr<Context>& context);
+    explicit ATrailersContentHandler(const std::shared_ptr<Context>& context)
+        : CurlContentHandler(context)
+    {
+    }
 
     /// \brief Sets the service XML from which we will extract the objects.
     /// \return false if service XML contained an error status.
-    void setServiceContent(std::unique_ptr<pugi::xml_document>& service) override;
+    void setServiceContent(std::unique_ptr<pugi::xml_document> service) override;
 
     /// \brief retrieves an object from the service.
     ///
