@@ -32,14 +32,7 @@
 #ifdef ATRAILERS
 #include "atrailers_service.h" // API
 
-#include <string>
-
-#include "config/config_manager.h"
-#include "config/config_options.h"
 #include "content/content_manager.h"
-#include "database/database.h"
-#include "util/string_converter.h"
-#include "util/url.h"
 
 #define ATRAILERS_SERVICE_URL_640 "https://trailers.apple.com/trailers/home/xml/current.xml"
 #define ATRAILERS_SERVICE_URL_720P "https://trailers.apple.com/trailers/home/xml/current_720p.xml"
@@ -58,7 +51,7 @@ std::unique_ptr<CurlContentHandler> ATrailersService::getContentHandler() const
     return std::make_unique<ATrailersContentHandler>(content->getContext());
 }
 
-service_type_t ATrailersService::getServiceType()
+service_type_t ATrailersService::getServiceType() const
 {
     return OS_ATrailers;
 }
