@@ -35,10 +35,6 @@
 #ifndef __SOPCAST_CONTENT_HANDLER_H__
 #define __SOPCAST_CONTENT_HANDLER_H__
 
-#include <memory>
-#include <pugixml.hpp>
-
-#include "context.h"
 #include "curl_online_service.h"
 
 #define SOPCAST_SERVICE "SopCast"
@@ -57,11 +53,14 @@ class CdsObject;
 /// metadata XML.
 class SopCastContentHandler : public CurlContentHandler {
 public:
-    explicit SopCastContentHandler(const std::shared_ptr<Context>& context);
+    explicit SopCastContentHandler(const std::shared_ptr<Context>& context)
+        : CurlContentHandler(context)
+    {
+    }
 
     /// \brief Sets the service XML from which we will extract the objects.
     /// \return false if service XML contained an error status.
-    void setServiceContent(std::unique_ptr<pugi::xml_document>& service) override;
+    void setServiceContent(std::unique_ptr<pugi::xml_document> service) override;
 
     /// \brief retrieves an object from the service.
     ///
@@ -73,11 +72,7 @@ public:
     std::shared_ptr<CdsObject> getNextObject() override;
 
 protected:
-    static std::shared_ptr<CdsObject> getObject(const std::string& groupName, const pugi::xml_node& channel);
-
-protected:
-    std::shared_ptr<Config> config;
-    std::shared_ptr<Database> database;
+    std::shared_ptr<CdsObject> getObject(const std::string& groupName, const pugi::xml_node& channel);
 
     std::unique_ptr<pugi::xml_document> service_xml;
     pugi::xml_node_iterator group_it;
