@@ -83,7 +83,7 @@ duk_ret_t js_addContainerTree(duk_context* ctx)
             }
             duk_to_object(ctx, -1);
             auto cds_obj = self->dukObject2cdsObject(nullptr);
-            if (cds_obj != nullptr) {
+            if (cds_obj) {
                 result.emplace_back(cds_obj);
             } else {
                 log_js("js_addContainerTree: no CdsObject at {}", i);
@@ -122,8 +122,6 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
     std::string containerclass;
     if (!duk_is_null_or_undefined(ctx, 2)) {
         containerclass = duk_to_string(ctx, 2);
-        if (containerclass.empty())
-            containerclass = nullptr;
     }
     //stack: js_cds_obj path containerclass
 
@@ -152,7 +150,7 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
         }
 
         auto orig_object = self->dukObject2cdsObject(self->getProcessedObject());
-        if (orig_object == nullptr)
+        if (!orig_object)
             return 0;
 
         std::shared_ptr<CdsObject> cds_obj;
@@ -194,11 +192,11 @@ duk_ret_t js_addCdsObject(duk_context* ctx)
         } else
             cds_obj = self->dukObject2cdsObject(orig_object);
 
-        if (cds_obj == nullptr) {
+        if (!cds_obj) {
             return 0;
         }
 
-        std::pair<int, bool> parentId = { stoiString(ts), false };
+        auto parentId = std::pair(stoiString(ts), false);
 
         if (parentId.first <= 0) {
             if ((self->whoami() == S_PLAYLIST) && (self->getConfig()->getBoolOption(CFG_IMPORT_SCRIPTING_PLAYLIST_SCRIPT_LINK_OBJECTS))) {
