@@ -67,13 +67,13 @@ public:
     Script(const Script&) = delete;
     Script& operator=(const Script&) = delete;
 
-    std::string getProperty(const std::string& name);
-    int getBoolProperty(const std::string& name);
-    int getIntProperty(const std::string& name, int def);
+    std::string getProperty(const std::string& name) const;
+    int getBoolProperty(const std::string& name) const;
+    int getIntProperty(const std::string& name, int def) const;
 
     void setProperty(const std::string& name, const std::string& value);
     void setIntProperty(const std::string& name, int value);
-    std::vector<std::string> getPropertyNames();
+    std::vector<std::string> getPropertyNames() const;
 
     void defineFunction(const std::string& name, duk_c_function function, uint32_t numParams);
     void defineFunctions(const duk_function_list_entry* functions);
@@ -100,7 +100,7 @@ protected:
         const std::shared_ptr<ScriptingRuntime>& runtime, const std::string& name);
 
     void execute();
-    int gc_counter;
+    int gc_counter {};
 
     // object that is currently being processed by the script (set in import
     // script)
@@ -108,7 +108,6 @@ protected:
 
     duk_context* ctx;
 
-protected:
     std::shared_ptr<Config> config;
     std::shared_ptr<Database> database;
     std::shared_ptr<ContentManager> content;
