@@ -46,6 +46,7 @@ class AutoscanList;
 class CdsObject;
 class Config;
 class ConfigValue;
+class Mime;
 enum class ScanMode;
 class Timer;
 
@@ -59,23 +60,23 @@ class Timer;
 class BrowseParam {
 protected:
     unsigned int flags;
-    int objectID;
+    std::shared_ptr<CdsObject> object;
 
     int startingIndex {};
     int requestedCount {};
     std::string sortCrit;
 
     // output parameters
-    int totalMatches;
+    int totalMatches {};
 
 public:
-    BrowseParam(int objectID, unsigned int flags)
+    BrowseParam(std::shared_ptr<CdsObject> object, unsigned int flags)
         : flags(flags)
-        , objectID(objectID)
+        , object(std::move(object))
     {
     }
 
-    int getFlags() const { return flags; }
+    unsigned int getFlags() const { return flags; }
     unsigned int getFlag(unsigned int mask) const { return flags & mask; }
     void setFlags(unsigned int flags) { this->flags = flags; }
     void setFlag(unsigned int mask) { flags |= mask; }
@@ -88,7 +89,7 @@ public:
     }
     void clearFlag(unsigned int mask) { flags &= !mask; }
 
-    int getObjectID() const { return objectID; }
+    std::shared_ptr<CdsObject> getObject() const { return object; }
 
     void setRange(int startingIndex, int requestedCount)
     {
@@ -139,6 +140,7 @@ public:
         , requestedCount(requestedCount)
     {
     }
+    const std::string& getContainerId() const { return containerID; }
     const std::string& searchCriteria() const { return searchCrit; }
     int getStartingIndex() const { return startingIndex; }
     int getRequestedCount() const { return requestedCount; }
@@ -147,7 +149,10 @@ public:
 
 class Database {
 public:
-    explicit Database(std::shared_ptr<Config> config);
+    explicit Database(std::shared_ptr<Config> config)
+        : config(std::move(config))
+    {
+    }
     virtual ~Database() = default;
     virtual void init() = 0;
 
@@ -183,7 +188,7 @@ public:
     /// It will be escaped.
     virtual fs::path buildContainerPath(int parentID, const std::string& title) = 0;
 
-    virtual void updateObject(std::shared_ptr<CdsObject> object, int* changedContainer) = 0;
+    virtual void updateObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) = 0;
 
     virtual std::vector<std::shared_ptr<CdsObject>> browse(const std::unique_ptr<BrowseParam>& param) = 0;
     virtual std::vector<std::shared_ptr<CdsObject>> search(const std::unique_ptr<SearchParam>& param, int* numMatches) = 0;
@@ -211,7 +216,7 @@ public:
     /// \param size number of entries in the given array
     /// \return a String for UPnP: a CSV list; for every existing object:
     ///  "id,update_id"
-    virtual std::string incrementUpdateIDs(const std::unique_ptr<std::unordered_set<int>>& ids) = 0;
+    virtual std::string incrementUpdateIDs(const std::unordered_set<int>& ids) = 0;
 
     /* utility methods */
     virtual std::shared_ptr<CdsObject> loadObject(int objectID) = 0;
@@ -301,18 +306,15 @@ public:
     virtual void threadCleanup() = 0;
     virtual bool threadCleanupRequired() const = 0;
 
-    virtual void doMetadataMigration() = 0;
-
 protected:
     /* helper for addContainerChain */
     static void stripAndUnescapeVirtualContainerFromPath(std::string path, std::string& first, std::string& last);
 
-    static std::shared_ptr<Database> createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Timer>& timer);
+    static std::shared_ptr<Database> createInstance(const std::shared_ptr<Config>& config, const std::shared_ptr<Mime>& mime, const std::shared_ptr<Timer>& timer);
     friend class Server;
 
     virtual std::shared_ptr<Database> getSelf() = 0;
 
-protected:
     std::shared_ptr<Config> config;
 };
 
