@@ -32,17 +32,23 @@
 #ifndef __SQL_STORAGE_H__
 #define __SQL_STORAGE_H__
 
+#include <array>
 #include <mutex>
 #include <sstream>
 #include <unordered_set>
 #include <utility>
 
+#include "config/config.h"
 #include "database.h"
 
-// forward declaration
+// forward declarations
+class CdsContainer;
+class CdsResource;
 class SQLResult;
 class SQLEmitter;
 
+#define DBVERSION 13
+
 #define QTB table_quote_begin
 #define QTE table_quote_end
 
@@ -50,22 +56,20 @@ class SQLEmitter;
 #define INTERNAL_SETTINGS_TABLE "mt_internal_setting"
 #define AUTOSCAN_TABLE "mt_autoscan"
 #define METADATA_TABLE "mt_metadata"
+#define RESOURCE_TABLE "grb_cds_resource"
 #define CONFIG_VALUE_TABLE "grb_config_value"
 
 class SQLRow {
 public:
-    //SQLRow() { }
-    //virtual ~SQLRow();
+    virtual ~SQLRow() = default;
     std::string col(int index) const
     {
         char* c = col_c_str(index);
-        if (c == nullptr)
+        if (!c)
             return "";
         return std::string(c);
     }
     virtual char* col_c_str(int index) const = 0;
-
-    virtual ~SQLRow() = default;
 };
 
 class SQLResult {
@@ -90,12 +94,13 @@ public:
     virtual std::string quote(char val) const = 0;
     virtual std::string quote(long long val) const = 0;
 
-    virtual void beginTransaction(const std::string_view& tName) = 0;
-    virtual void rollback(const std::string_view& tName) = 0;
-    virtual void commit(const std::string_view& tName) = 0;
+    // hooks for transactions
+    virtual void beginTransaction(const std::string_view& tName) { }
+    virtual void rollback(const std::string_view& tName) { }
+    virtual void commit(const std::string_view& tName) { }
 
-    virtual std::shared_ptr<SQLResult> select(const char* query, int length) = 0;
-    virtual int exec(const char* query, int length, bool getLastInsertId = false) = 0;
+    virtual std::shared_ptr<SQLResult> select(const char* query, size_t length) = 0;
+    virtual int exec(const char* query, size_t length, bool getLastInsertId = false) = 0;
 
     /* wrapper functions for select and exec */
     std::shared_ptr<SQLResult> select(const std::string& buf)
@@ -113,7 +118,7 @@ public:
     }
 
     void addObject(std::shared_ptr<CdsObject> object, int* changedContainer) override;
-    void updateObject(std::shared_ptr<CdsObject> object, int* changedContainer) override;
+    void updateObject(const std::shared_ptr<CdsObject>& object, int* changedContainer) override;
 
     std::shared_ptr<CdsObject> loadObject(int objectID) override;
     int getChildCount(int contId, bool containers, bool items, bool hideFsRoot) override;
@@ -137,7 +142,7 @@ public:
     //virtual std::shared_ptr<CdsObject> findObjectByTitle(std::string title, int parentID);
     std::shared_ptr<CdsObject> findObjectByPath(fs::path fullpath, bool wasRegularFile = false) override;
     int findObjectIDByPath(fs::path fullpath, bool wasRegularFile = false) override;
-    std::string incrementUpdateIDs(const std::unique_ptr<std::unordered_set<int>>& ids) override;
+    std::string incrementUpdateIDs(const std::unordered_set<int>& ids) override;
 
     fs::path buildContainerPath(int parentID, const std::string& title) override;
     void addContainerChain(std::string path, const std::string& lastClass, int lastRefID, int* containerID, std::vector<int>& updateID, const std::map<std::string, std::string>& lastMetadata) override;
@@ -167,33 +172,51 @@ public:
 
     std::string getFsRootName() override;
     static std::string getSortCapabilities();
+    static std::string getSearchCapabilities();
 
     void clearFlagInDB(int flag) override;
+    unsigned int getHash(size_t index) { return index < DBVERSION ? hashies[index] : 0; }
 
 protected:
-    explicit SQLDatabase(std::shared_ptr<Config> config);
-    //virtual ~SQLDatabase();
+    explicit SQLDatabase(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime);
     void init() override;
 
-    void doMetadataMigration() override;
-    void migrateMetadata(const std::shared_ptr<CdsObject>& object);
+    /// \brief migrate metadata from mt_cds_objects to mt_metadata before removing the column (DBVERSION 12)
+    bool doMetadataMigration();
+    void migrateMetadata(int objectId, const std::string& metadataStr);
 
-    char table_quote_begin;
-    char table_quote_end;
-    bool use_transaction;
-    bool inTransaction;
+    /// \brief Add a column to resource table for each defined resource attribute
+    void prepareResourceTable(std::string_view addColumnCmd);
+
+    /// \brief migrate resources from mt_cds_objects to grb_resource before removing the column (DBVERSION 13)
+    bool doResourceMigration();
+    void migrateResources(int objectId, const std::string& resourcesStr);
+
+    std::shared_ptr<Mime> mime;
+
+    char table_quote_begin { '\0' };
+    char table_quote_end { '\0' };
+    std::array<unsigned int, DBVERSION> hashies;
 
     std::recursive_mutex sqlMutex;
     using SqlAutoLock = std::lock_guard<decltype(sqlMutex)>;
+    std::map<int, std::shared_ptr<CdsContainer>> dynamicContainers;
+
+    void upgradeDatabase(std::string&& dbVersion, const std::array<unsigned int, DBVERSION>& hashies, config_option_t upgradeOption, std::string_view updateVersionCommand, std::string_view addResourceColumnCmd);
+    virtual void _exec(const char* query, int length = -1) = 0;
 
 private:
     std::string sql_browse_query;
+    std::string sql_search_columns;
     std::string sql_search_query;
     std::string sql_meta_query;
+    std::string sql_resource_query;
+    std::string addResourceColumnCmd;
 
     std::shared_ptr<CdsObject> createObjectFromRow(const std::unique_ptr<SQLRow>& row);
     std::shared_ptr<CdsObject> createObjectFromSearchRow(const std::unique_ptr<SQLRow>& row);
     std::map<std::string, std::string> retrieveMetadataForObject(int objectId);
+    std::vector<std::shared_ptr<CdsResource>> retrieveResourcesForObject(int objectId);
 
     enum class Operation {
         Insert,
@@ -224,9 +247,12 @@ private:
     void generateMetadataDBOperations(const std::shared_ptr<CdsObject>& obj, Operation op,
         std::vector<std::shared_ptr<AddUpdateTable>>& operations);
 
-    std::unique_ptr<std::ostringstream> sqlForInsert(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
-    std::unique_ptr<std::ostringstream> sqlForUpdate(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
-    std::unique_ptr<std::ostringstream> sqlForDelete(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
+    void generateResourceDBOperations(const std::shared_ptr<CdsObject>& obj, Operation op,
+        std::vector<std::shared_ptr<AddUpdateTable>>& operations);
+
+    std::ostringstream sqlForInsert(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
+    std::ostringstream sqlForUpdate(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
+    std::ostringstream sqlForDelete(const std::shared_ptr<CdsObject>& obj, const std::shared_ptr<AddUpdateTable>& addUpdateTable) const;
 
     /* helper for removeObject(s) */
     void _removeObjects(const std::vector<int32_t>& objectIDs);
@@ -237,7 +263,7 @@ private:
         const std::vector<int32_t>& items,
         const std::vector<int32_t>& containers, bool all);
 
-    virtual std::unique_ptr<ChangedContainers> _purgeEmptyContainers(std::unique_ptr<ChangedContainers>& maybeEmpty);
+    virtual std::unique_ptr<ChangedContainers> _purgeEmptyContainers(const std::unique_ptr<ChangedContainers>& maybeEmpty);
 
     /* helpers for autoscan */
     void _removeAutoscanDirectory(int autoscanID);
@@ -249,7 +275,7 @@ private:
     /* location helper: filesystem path or virtual path to db location*/
     static std::string addLocationPrefix(char prefix, const fs::path& path);
     /* location helpers: db location to filesystem path */
-    static fs::path stripLocationPrefix(const std::string& dbLocation, char* prefix = nullptr);
+    static fs::path stripLocationPrefix(std::string_view dbLocation, char* prefix = nullptr);
 
     std::shared_ptr<CdsObject> checkRefID(const std::shared_ptr<CdsObject>& obj);
     int createContainer(int parentID, std::string name, const std::string& virtualPath, bool isVirtual, const std::string& upnpClass, int refID, const std::map<std::string, std::string>& itemMetadata);
@@ -265,4 +291,15 @@ private:
     using AutoLock = std::lock_guard<std::mutex>;
 };
 
+class SqlWithTransactions {
+protected:
+    explicit SqlWithTransactions(const std::shared_ptr<Config>& config)
+        : use_transaction(config->getBoolOption(CFG_SERVER_STORAGE_USE_TRANSACTIONS))
+    {
+    }
+
+    bool use_transaction;
+    bool inTransaction {};
+};
+
 #endif // __SQL_STORAGE_H__
