@@ -48,8 +48,7 @@ class Sqlite3Result;
 /// \brief A virtual class that represents a task to be done by the sqlite3 thread.
 class SLTask {
 public:
-    /// \brief Instantiate a task
-    SLTask() = default;
+    virtual ~SLTask() = default;
 
     /// \brief run the sqlite3 task
     /// \param sl The instance of Sqlite3Database to do the queries with.
@@ -71,8 +70,6 @@ public:
 
     std::string getError() const { return error; }
 
-    virtual ~SLTask() = default;
-
     virtual std::string_view taskType() const = 0;
 
 protected:
@@ -82,10 +79,10 @@ protected:
     bool running { true };
 
     /// \brief true if this task has changed the db (in comparison to the backup)
-    bool contamination { false };
+    bool contamination {};
 
     /// \brief true if this task has backuped the db
-    bool decontamination { false };
+    bool decontamination {};
 
     std::condition_variable cond;
     std::mutex mutex;
@@ -97,13 +94,18 @@ protected:
 class SLInitTask : public SLTask {
 public:
     /// \brief Constructor for the sqlite3 init task
-    explicit SLInitTask(std::shared_ptr<Config> config);
+    explicit SLInitTask(std::shared_ptr<Config> config, unsigned int hashie)
+        : config(std::move(config))
+        , hashie(hashie)
+    {
+    }
     void run(sqlite3** db, Sqlite3Database* sl) override;
 
     std::string_view taskType() const override { return "InitTask"; }
 
 protected:
     std::shared_ptr<Config> config;
+    unsigned int hashie;
 };
 
 /// \brief A task for the sqlite3 thread to do a SQL select.
@@ -111,7 +113,10 @@ class SLSelectTask : public SLTask {
 public:
     /// \brief Constructor for the sqlite3 select task
     /// \param query The SQL query string
-    explicit SLSelectTask(const char* query);
+    explicit SLSelectTask(const char* query)
+        : query(query)
+    {
+    }
     void run(sqlite3** db, Sqlite3Database* sl) override;
     [[nodiscard]] std::shared_ptr<SQLResult> getResult() const { return std::static_pointer_cast<SQLResult>(pres); }
 
@@ -139,7 +144,7 @@ protected:
     /// \brief The SQL query string
     const char* query;
 
-    int lastInsertId;
+    int lastInsertId {};
     bool getLastInsertIdFlag;
 };
 
@@ -161,7 +166,10 @@ protected:
 class Sqlite3Database : public Timer::Subscriber, public SQLDatabase, public std::enable_shared_from_this<SQLDatabase> {
 public:
     void timerNotify(std::shared_ptr<Timer::Parameter> param) override;
-    Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Timer> timer);
+    Sqlite3Database(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer);
+
+protected:
+    void _exec(const char* query, int length = -1) override;
 
 private:
     void prepare();
@@ -180,17 +188,11 @@ private:
     std::string quote(char val) const override { return quote(std::string(1, val)); }
     std::string quote(long long val) const override { return fmt::to_string(val); }
 
-    std::shared_ptr<SQLResult> select(const char* query, int length) override;
-    int exec(const char* query, int length, bool getLastInsertId = false) override;
-
-    void beginTransaction(const std::string_view& tName) override;
-    void rollback(const std::string_view& tName) override;
-    void commit(const std::string_view& tName) override;
+    std::shared_ptr<SQLResult> select(const char* query, size_t length) override;
+    int exec(const char* query, size_t length, bool getLastInsertId = false) override;
 
     void storeInternalSetting(const std::string& key, const std::string& value) override;
 
-    void _exec(const char* query);
-
     std::string startupError;
 
     std::string getError(const std::string& query, const std::string& error, sqlite3* db, int errorCode);
@@ -204,19 +206,19 @@ private:
     std::shared_ptr<Timer> timer;
 
     /// \brief is set to true by shutdown() if the sqlite3 thread should terminate
-    bool shutdownFlag;
+    bool shutdownFlag {};
 
     /// \brief the tasks to be done by the sqlite3 thread
     std::queue<std::shared_ptr<SLTask>> taskQueue;
-    bool taskQueueOpen;
+    bool taskQueueOpen {};
 
     void threadCleanup() override { }
     bool threadCleanupRequired() const override { return false; }
 
-    bool dirty;
-    bool dbInitDone;
-    bool hasBackupTimer;
-    int sqliteStatus;
+    bool dirty {};
+    bool dbInitDone {};
+    bool hasBackupTimer {};
+    int sqliteStatus {};
 
     friend class SLSelectTask;
     friend class SLExecTask;
@@ -224,6 +226,19 @@ private:
     friend class Sqlite3BackupTimerSubscriber;
 };
 
+/// \brief The Database class for using SQLite3 with transactions
+class Sqlite3DatabaseWithTransactions : public SqlWithTransactions, public Sqlite3Database {
+public:
+    Sqlite3DatabaseWithTransactions(std::shared_ptr<Config> config, std::shared_ptr<Mime> mime, std::shared_ptr<Timer> timer)
+        : SqlWithTransactions(config)
+        , Sqlite3Database(std::move(config), std::move(mime), std::move(timer))
+    {
+    }
+    void beginTransaction(const std::string_view& tName) override;
+    void rollback(const std::string_view& tName) override;
+    void commit(const std::string_view& tName) override;
+};
+
 /// \brief Represents a result of a sqlite3 select
 class Sqlite3Result : public SQLResult {
 public:
@@ -253,7 +268,10 @@ private:
 /// \brief Represents a row of a result of a sqlite3 select
 class Sqlite3Row : public SQLRow {
 public:
-    explicit Sqlite3Row(char** row);
+    explicit Sqlite3Row(char** row)
+        : row(row)
+    {
+    }
 
 private:
     char* col_c_str(int index) const override { return row[index]; }
