@@ -35,6 +35,8 @@
 /// running "doxygen doxygen.conf" from the mediatomb/doc/ directory.
 
 #include <csignal>
+#include <cstdio>
+#include <cstdlib>
 #include <filesystem>
 #include <mutex>
 #include <spdlog/sinks/basic_file_sink.h>
@@ -55,9 +57,6 @@
 #include <fcntl.h>
 #include <grp.h>
 #include <pwd.h>
-#include <signal.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <sys/stat.h>
 #include <sys/types.h>
 #include <unistd.h>
@@ -240,9 +239,8 @@ int main(int argc, char** argv, char** envp)
             uid_t actual_euid = geteuid();
 
             // get user info of requested user from passwd
-            struct passwd* user_id = getpwnam(user->c_str());
-
-            if (user_id == nullptr) {
+            auto user_id = getpwnam(user->c_str());
+            if (!user_id) {
                 log_error("Invalid user requested.");
                 exit(EXIT_FAILURE);
             }
@@ -262,7 +260,7 @@ int main(int argc, char** argv, char** envp)
 // mac os x does this differently, setgid and setuid are basically doing the same
 // as setresuid and setresgid on linux: setting all of real{u,g}id, effective{u,g}id and saved-set{u,g}id
 // Solaroid systems are likewise missing setresgid and setresuid
-#if defined(__APPLE__) || defined(SOLARIS) || defined(__CYGWIN__)
+#if defined(__APPLE__) || defined(SOLARIS) || defined(__CYGWIN__) || defined(__HAIKU__)
             // set group-ids, then add. groups, last user-ids, all need to succeed
             if (0 != setgid(user_id->pw_gid) || 0 != initgroups(user_id->pw_name, user_id->pw_gid) || 0 != setuid(user_id->pw_uid)) {
 #else
@@ -316,7 +314,7 @@ int main(int argc, char** argv, char** envp)
                 exit(EXIT_FAILURE);
             }
             // close open filedescriptors belonging to a tty
-            for (int fd = sysconf(_SC_OPEN_MAX); fd >= 0; fd--) {
+            for (auto fd = int(sysconf(_SC_OPEN_MAX)); fd >= 0; fd--) {
                 if (isatty(fd))
                     close(fd);
             }
@@ -328,47 +326,31 @@ int main(int argc, char** argv, char** envp)
         if (opts.count("pidfile") > 0) {
             pidfile = opts["pidfile"].as<std::string>();
 
-            // exit if the pidfile already exists
-            struct stat s;
-            errno = 0;
-            // for pidfile to be not there stat needs to fail and it needs
-            // to fail due to ENOENT (no such file or dir)
-            if (!(-1 == stat(pidfile->c_str(), &s) && errno == ENOENT)) {
+            // x will make it fail if file exists
+            auto pidf = ::fopen(pidfile->c_str(), "wx");
+            if (!pidf) {
                 log_error("Pidfile {} exists. It may be that gerbera is already", pidfile->c_str());
                 log_error("running or the file is a leftover from an unclean shutdown.");
                 log_error("In that case, remove the file before starting gerbera.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
             // get the pid of our process
             pid_t pid = getpid();
-
-            // convert to a string
-            char pidstr[20];
-            if (0 > snprintf(pidstr, 18, "%d", pid)) {
+            if (pid <= 1) {
                 log_error("Could not determine pid of running process.");
-                exit(EXIT_FAILURE);
+                std::exit(EXIT_FAILURE);
             }
 
-            // add a newline
-            strcat(pidstr, "\n");
-
-            // open the pidfile
-            int pidfd = open(pidfile->c_str(), O_CREAT | O_WRONLY, S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH);
-            if (-1 == pidfd) {
-                log_error("Could not create pidfile {}.", pidfile->c_str());
-                exit(EXIT_FAILURE);
-            }
-
-            // write pid to file
-            if (ssize_t(strlen(pidstr)) != write(pidfd, pidstr, strlen(pidstr))) {
-                log_error("Could not write pidfile {}.", pidfile->c_str());
-                exit(EXIT_FAILURE);
+            try {
+                // write pid to file
+                fmt::print(pidf, "{}\n", pid);
+            } catch (const std::system_error& ex) {
+                log_error("Could not write pidfile {}: {}.", pidfile->c_str(), ex.what());
+                std::exit(EXIT_FAILURE);
             }
             log_debug("Wrote pidfile {}.", pidfile->c_str());
-
-            // close filedescriptor
-            close(pidfd);
+            ::fclose(pidf);
         }
 
         std::optional<std::string> config_file;
@@ -389,13 +371,13 @@ int main(int argc, char** argv, char** envp)
         if (!config_file.has_value() && !home.has_value()) {
             // Check XDG first
             const char* h = std::getenv("XDG_CONFIG_HOME");
-            if (h != nullptr) {
+            if (h) {
                 home = h;
                 confdir = "gerbera";
             } else {
                 // Then look for home
                 h = std::getenv("HOME");
-                if (h != nullptr)
+                if (h)
                     home = h;
             }
 
@@ -408,11 +390,11 @@ int main(int argc, char** argv, char** envp)
 
         std::optional<std::string> dataDir;
         char* pref = std::getenv("GERBERA_DATADIR");
-        if (pref != nullptr) {
+        if (pref) {
             dataDir = pref;
         } else {
             pref = std::getenv("MEDIATOMB_DATADIR");
-            if (pref != nullptr)
+            if (pref)
                 dataDir = pref;
         }
         if (!dataDir.has_value())
@@ -420,17 +402,19 @@ int main(int argc, char** argv, char** envp)
 
         std::optional<std::string> magic;
         char* mgc = std::getenv("GERBERA_MAGIC_FILE");
-        if (mgc != nullptr) {
+        if (mgc) {
             magic = mgc;
         } else {
             mgc = std::getenv("MEDIATOMB_MAGIC_FILE");
-            if (mgc != nullptr)
+            if (mgc)
                 magic = mgc;
         }
 
         if (opts.count("create-config") > 0) {
             ConfigGenerator configGenerator;
-
+            if (opts.count("cfgdir") == 0) {
+                confdir = "";
+            }
             std::string generated = configGenerator.generate(home.value_or(""), confdir.value_or(""), dataDir.value_or(""), magic.value_or(""));
             std::cout << generated.c_str() << std::endl;
             exit(EXIT_SUCCESS);
@@ -483,7 +467,6 @@ int main(int argc, char** argv, char** envp)
             server->init();
             server->run();
         } catch (const UpnpException& ue) {
-
             sigemptyset(&mask_set);
             pthread_sigmask(SIG_SETMASK, &mask_set, nullptr);
 
@@ -615,7 +598,6 @@ int main(int argc, char** argv, char** envp)
 
         log_info("Gerbera exiting. Have a nice day.");
         exit(ret);
-
     } catch (const cxxopts::OptionException& e) {
         std::cerr << "Failed to parse arguments: " << e.what() << std::endl;
         exit(EXIT_FAILURE);
