@@ -46,12 +46,15 @@ namespace fs = std::filesystem;
 #include "metadata_handler.h"
 
 // forward declaration
-class AVFormatContext;
+struct AVFormatContext;
 
 /// \brief This class is responsible for reading id3 tags metadata
 class FfmpegHandler : public MetadataHandler {
 public:
-    explicit FfmpegHandler(const std::shared_ptr<Context>& context);
+    explicit FfmpegHandler(const std::shared_ptr<Context>& context)
+        : MetadataHandler(context)
+    {
+    }
     void fillMetadata(std::shared_ptr<CdsObject> obj) override;
     std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
     std::string getMimeType() override;
@@ -68,7 +71,7 @@ private:
     void writeThumbnailCacheFile(const fs::path& movie_filename, const std::byte* data, std::size_t size) const;
 };
 
-fs::path getThumbnailCacheBasePath(Config& config);
+fs::path getThumbnailCacheBasePath(const Config& config);
 fs::path getThumbnailCachePath(const fs::path& base, const fs::path& movie);
 
 #endif //__FFMPEG_HANDLER_H__
