@@ -59,7 +59,10 @@ private:
     void process_ifd(ExifContent* content, const std::shared_ptr<CdsItem>& item, const std::unique_ptr<StringConverter>& sc, const std::vector<std::string>& auxtags);
 
 public:
-    explicit LibExifHandler(const std::shared_ptr<Context>& context);
+    explicit LibExifHandler(const std::shared_ptr<Context>& context)
+        : MetadataHandler(context)
+    {
+    }
     void fillMetadata(std::shared_ptr<CdsObject> obj) override;
     std::unique_ptr<IOHandler> serveContent(std::shared_ptr<CdsObject> obj, int resNum) override;
 };
