@@ -51,7 +51,6 @@
 #include "config/config_manager.h"
 #include "iohandler/mem_io_handler.h"
 #include "util/mime.h"
-#include "util/string_converter.h"
 #include "util/tools.h"
 
 TagLibHandler::TagLibHandler(const std::shared_ptr<Context>& context)
@@ -63,7 +62,7 @@ TagLibHandler::TagLibHandler(const std::shared_ptr<Context>& context)
 
 void TagLibHandler::addField(metadata_fields_t field, const TagLib::File& file, const TagLib::Tag* tag, const std::shared_ptr<CdsItem>& item) const
 {
-    if (tag == nullptr)
+    if (!tag)
         return;
 
     if (tag->isEmpty())
@@ -206,10 +205,36 @@ void TagLibHandler::populateGenericTags(const std::shared_ptr<CdsItem>& item, co
     }
 }
 
+void TagLibHandler::populateAuxTags(const std::shared_ptr<CdsItem>& item, const TagLib::PropertyMap& propertyMap, const std::unique_ptr<StringConverter>& sc) const
+{
+    auto aux_tags_list = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
+    for (auto&& desiredTag : aux_tags_list) {
+        if (desiredTag.empty()) {
+            continue;
+        }
+
+        if (propertyMap.contains(desiredTag.c_str())) {
+            const auto property = propertyMap[desiredTag.c_str()];
+            if (property.isEmpty())
+                continue;
+
+            auto val = property.toString(entrySeparator);
+            if (!legacyEntrySeparator.empty())
+                val = val.split(legacyEntrySeparator).toString(entrySeparator);
+            std::string value(val.toCString(true));
+            value = sc->convert(value);
+            log_debug("Adding auxdata: {} with value {}", desiredTag.c_str(), value.c_str());
+            item->setAuxData(desiredTag, value);
+        }
+    }
+}
+
+/// \brief read metadata from file and add to object
+/// \param obj Object to handle
 void TagLibHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (item == nullptr)
+    if (!item)
         return;
 
     auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
@@ -239,20 +264,18 @@ void TagLibHandler::fillMetadata(std::shared_ptr<CdsObject> obj)
     log_debug("TagLib handler done.");
 }
 
-bool TagLibHandler::isValidArtworkContentType(const std::string& art_mimetype)
+bool TagLibHandler::isValidArtworkContentType(std::string_view art_mimetype)
 {
     // saw that simply "PNG" was used with some mp3's, so mimetype setting
     // was probably invalid
-    return art_mimetype.find('/') != std::string::npos;
+    return art_mimetype.find('/') != std::string_view::npos;
 }
 
 std::string TagLibHandler::getContentTypeFromByteVector(const TagLib::ByteVector& data) const
 {
 #ifdef HAVE_MAGIC
     auto art_mimetype = mime->bufferToMimeType(data.data(), data.size());
-    if (art_mimetype.empty())
-        return MIMETYPE_DEFAULT;
-    return art_mimetype;
+    return art_mimetype.empty() ? MIMETYPE_DEFAULT : art_mimetype;
 #else
     return MIMETYPE_DEFAULT;
 #endif
@@ -268,14 +291,18 @@ void TagLibHandler::addArtworkResource(const std::shared_ptr<CdsItem>& item, con
         auto resource = std::make_shared<CdsResource>(CH_ID3);
         resource->addAttribute(R_PROTOCOLINFO, renderProtocolInfo(art_mimetype));
         resource->addParameter(RESOURCE_CONTENT_TYPE, ID3_ALBUM_ART);
-        item->addResource(resource);
+        item->addResource(move(resource));
     }
 }
 
+/// \brief stream content of object or resource to client
+/// \param obj Object to stream
+/// \param resNum number of resource
+/// \return iohandler to stream to client
 std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject> obj, int resNum)
 {
     auto item = std::dynamic_pointer_cast<CdsItem>(obj);
-    if (item == nullptr)
+    if (!item) // not streamable
         return nullptr;
 
     auto mappings = config->getDictionaryOption(CFG_IMPORT_MAPPINGS_MIMETYPE_TO_CONTENTTYPE_LIST);
@@ -284,7 +311,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject
     TagLib::FileStream roStream(item->getLocation().c_str(), true); // Open read only
 
     if (content_type == CONTENT_TYPE_MP3) {
-
+        // stream album art from MP3 file
         TagLib::MPEG::File f(&roStream, TagLib::ID3v2::FrameFactory::instance());
 
         if (!f.isValid())
@@ -298,10 +325,14 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject
             throw_std_runtime_error("resource has no album information");
 
         auto art = dynamic_cast<TagLib::ID3v2::AttachedPictureFrame*>(list.front());
+        if (!art) {
+            return nullptr;
+        }
 
         return std::make_unique<MemIOHandler>(art->picture().data(), art->picture().size());
     }
     if (content_type == CONTENT_TYPE_FLAC) {
+        // stream album art from FLAC file
         TagLib::FLAC::File f(&roStream, TagLib::ID3v2::FrameFactory::instance());
 
         if (!f.isValid())
@@ -316,6 +347,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
     if (content_type == CONTENT_TYPE_MP4) {
+        // stream album art from MP4 file
         TagLib::MP4::File f(&roStream);
 
         if (!f.isValid()) {
@@ -344,6 +376,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
     if (content_type == CONTENT_TYPE_WMA) {
+        // stream album art from WMA file
         TagLib::ASF::File f(&roStream);
 
         if (!f.isValid())
@@ -366,6 +399,7 @@ std::unique_ptr<IOHandler> TagLibHandler::serveContent(std::shared_ptr<CdsObject
         return std::make_unique<MemIOHandler>(data.data(), data.size());
     }
     if (content_type == CONTENT_TYPE_OGG) {
+        // stream album art from Ogg/Vorbis file
         TagLib::Ogg::Vorbis::File f(&roStream);
 
         if (!f.isValid() || !f.tag())
@@ -419,7 +453,7 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
             std::string value;
             for (auto&& frame : frameList) {
                 const auto textFrame = dynamic_cast<const TagLib::ID3v2::TextIdentificationFrame*>(frame);
-                if (textFrame == nullptr)
+                if (!textFrame)
                     continue;
                 TagLib::String frameContents = textFrame->fieldList().toString(entrySeparator);
                 if (!value.empty())
@@ -440,7 +474,7 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
 
             for (auto&& frame : frameList) {
                 const auto textFrame = dynamic_cast<const TagLib::ID3v2::TextIdentificationFrame*>(frame);
-                if (textFrame == nullptr)
+                if (!textFrame)
                     continue;
                 std::string content;
                 std::string subTag;
@@ -473,6 +507,9 @@ void TagLibHandler::extractMP3(TagLib::IOStream* roStream, const std::shared_ptr
     const TagLib::ID3v2::FrameList apicFrameList = mp3.ID3v2Tag()->frameList("APIC");
     if (!apicFrameList.isEmpty()) {
         auto art = dynamic_cast<const TagLib::ID3v2::AttachedPictureFrame*>(apicFrameList.front());
+        if (!art) {
+            return;
+        }
 
         const TagLib::ByteVector pic = art->picture();
         std::string art_mimetype = sc->convert(art->mimeType().toCString(true));
@@ -497,6 +534,10 @@ void TagLibHandler::extractOgg(TagLib::IOStream* roStream, const std::shared_ptr
     if (!vorbis.tag())
         return;
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = vorbis.properties();
+    populateAuxTags(item, propertyMap, sc);
+
     // Vorbis uses the FLAC binary picture structure...
     // https://wiki.xiph.org/VorbisComment#Cover_art
     // The unofficial COVERART field is not supported.
@@ -507,7 +548,6 @@ void TagLibHandler::extractOgg(TagLib::IOStream* roStream, const std::shared_ptr
     const TagLib::FLAC::Picture* pic = picList.front();
     const TagLib::ByteVector& data = pic->data();
 
-    auto sc = StringConverter::i2i(config);
     std::string art_mimetype = sc->convert(pic->mimeType().toCString(true));
     if (!isValidArtworkContentType(art_mimetype)) {
         art_mimetype = getContentTypeFromByteVector(data);
@@ -525,6 +565,10 @@ void TagLibHandler::extractASF(TagLib::IOStream* roStream, const std::shared_ptr
     }
     populateGenericTags(item, asf);
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = asf.properties();
+    populateAuxTags(item, propertyMap, sc);
+
     auto audioProps = asf.audioProperties();
     auto temp = audioProps->bitsPerSample();
     auto res = item->getResource(0);
@@ -542,7 +586,6 @@ void TagLibHandler::extractASF(TagLib::IOStream* roStream, const std::shared_ptr
         if (!wmpic.isValid())
             return;
 
-        auto sc = StringConverter::i2i(config);
         std::string art_mimetype = sc->convert(wmpic.mimeType().toCString(true));
         if (!isValidArtworkContentType(art_mimetype)) {
             art_mimetype = getContentTypeFromByteVector(wmpic.picture());
@@ -562,30 +605,8 @@ void TagLibHandler::extractFLAC(TagLib::IOStream* roStream, const std::shared_pt
     populateGenericTags(item, flac);
 
     auto sc = StringConverter::i2i(config);
-
-    std::vector<std::string> aux_tags_list = config->getArrayOption(CFG_IMPORT_LIBOPTS_ID3_AUXDATA_TAGS_LIST);
-    for (auto&& desiredTag : aux_tags_list) {
-
-        if (desiredTag.empty()) {
-            continue;
-        }
-
-        auto propertyMap = flac.properties();
-
-        if (propertyMap.contains(desiredTag.c_str())) {
-            const auto property = propertyMap[desiredTag.c_str()];
-            if (property.isEmpty())
-                continue;
-
-            auto val = property.toString(entrySeparator);
-            if (!legacyEntrySeparator.empty())
-                val = val.split(legacyEntrySeparator).toString(entrySeparator);
-            std::string value(val.toCString(true));
-            value = sc->convert(value);
-            log_debug("Adding auxdata: {} with value {}", desiredTag.c_str(), value.c_str());
-            item->setAuxData(desiredTag, value);
-        }
-    }
+    auto propertyMap = flac.properties();
+    populateAuxTags(item, propertyMap, sc);
 
     if (flac.pictureList().isEmpty()) {
         log_debug("TagLibHandler: flac resource has no picture information");
@@ -618,6 +639,10 @@ void TagLibHandler::extractAPE(TagLib::IOStream* roStream, const std::shared_ptr
     }
     populateGenericTags(item, ape);
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = ape.properties();
+    populateAuxTags(item, propertyMap, sc);
+
     auto audioProps = ape.audioProperties();
     auto temp = audioProps->bitsPerSample();
     auto res = item->getResource(0);
@@ -636,6 +661,10 @@ void TagLibHandler::extractWavPack(TagLib::IOStream* roStream, const std::shared
     }
     populateGenericTags(item, wavpack);
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = wavpack.properties();
+    populateAuxTags(item, propertyMap, sc);
+
     auto audioProps = wavpack.audioProperties();
     auto temp = audioProps->bitsPerSample();
     auto res = item->getResource(0);
@@ -660,6 +689,10 @@ void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr
         return;
     }
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = mp4.tag()->properties();
+    populateAuxTags(item, propertyMap, sc);
+
     auto audioProps = mp4.audioProperties();
     auto temp = audioProps->bitsPerSample();
     auto res = item->getResource(0);
@@ -677,8 +710,8 @@ void TagLibHandler::extractMP4(TagLib::IOStream* roStream, const std::shared_ptr
         }
 
         auto& coverArt = coverArtList.front();
-        if (auto art_mimetype = getContentTypeFromByteVector(coverArt.data());
-            !art_mimetype.empty()) {
+        auto art_mimetype = getContentTypeFromByteVector(coverArt.data());
+        if (!art_mimetype.empty()) {
             addArtworkResource(item, art_mimetype);
         }
     } else {
@@ -697,6 +730,10 @@ void TagLibHandler::extractAiff(TagLib::IOStream* roStream, const std::shared_pt
     }
     populateGenericTags(item, aiff);
 
+    auto sc = StringConverter::i2i(config);
+    auto propertyMap = aiff.properties();
+    populateAuxTags(item, propertyMap, sc);
+
     auto audioProps = aiff.audioProperties();
     auto temp = audioProps->bitsPerSample();
     auto res = item->getResource(0);
