@@ -52,7 +52,8 @@ class Server;
 
 class RequestHandler {
 public:
-    RequestHandler(std::shared_ptr<ContentManager> content);
+    explicit RequestHandler(std::shared_ptr<ContentManager> content);
+    virtual ~RequestHandler() = default;
 
     /// \brief Returns information about the requested content.
     /// \param filename Requested URL
@@ -79,9 +80,7 @@ public:
     static std::string joinUrl(const std::vector<std::string>& components, bool addToEnd = false, const std::string& separator = _URL_PARAM_SEPARATOR);
 
     static std::map<std::string, std::string> parseParameters(const char* filename, const char* baseLink);
-    std::shared_ptr<CdsObject> getObjectById(std::map<std::string, std::string> params);
-
-    virtual ~RequestHandler() = default;
+    std::shared_ptr<CdsObject> getObjectById(std::map<std::string, std::string> params) const;
 
 protected:
     std::shared_ptr<ContentManager> content;
