@@ -87,11 +87,10 @@ void ServeRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
         } else {
             UpnpFileInfo_set_IsReadable(info, 0);
         }
-
-#if defined(USING_NPUPNP)
-        UpnpFileInfo_set_ContentType(info, mimetype);
+#ifdef USING_NPUPNP
+        info->content_type = std::move(mimetype);
 #else
-        UpnpFileInfo_set_ContentType(info, ixmlCloneDOMString(mimetype.c_str()));
+        UpnpFileInfo_set_ContentType(info, mimetype.c_str());
 #endif
     } else {
         throw_std_runtime_error("Not a regular file: {}", path.c_str());
