@@ -38,6 +38,8 @@
 #include "request_handler.h"
 #include "transcoding/transcoding.h"
 
+std::vector<int> UpnpXMLBuilder::orderedHandler = {};
+
 UpnpXMLBuilder::UpnpXMLBuilder(const std::shared_ptr<Context>& context,
     std::string virtualUrl, std::string presentationURL)
     : config(context->getConfig())
@@ -45,6 +47,13 @@ UpnpXMLBuilder::UpnpXMLBuilder(const std::shared_ptr<Context>& context,
     , virtualURL(std::move(virtualUrl))
     , presentationURL(std::move(presentationURL))
 {
+    if (orderedHandler.empty())
+        for (auto&& entry : this->config->getArrayOption(CFG_IMPORT_RESOURCES_ORDER)) {
+            auto ch = MetadataHandler::remapContentHandler(entry);
+            if (ch > -1) {
+                orderedHandler.push_back(ch);
+            }
+        }
 }
 
 std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::createResponse(const std::string& actionName, const std::string& serviceType)
@@ -66,14 +75,39 @@ metadata_fields_t UpnpXMLBuilder::remapMetaDataField(const std::string& fieldNam
     return M_MAX;
 }
 
+void UpnpXMLBuilder::addPropertyList(pugi::xml_node& result, const std::map<std::string, std::string>& meta, const std::map<std::string, std::string>& auxData,
+    config_option_t itemProps, config_option_t nsProp)
+{
+    auto&& namespaceMap = config->getDictionaryOption(nsProp);
+    for (auto&& [xmlns, uri] : namespaceMap) {
+        result.append_attribute(fmt::format("xmlns:{}", xmlns).c_str()) = uri.c_str();
+    }
+    auto&& propertyMap = config->getDictionaryOption(itemProps);
+    for (auto&& [tag, field] : propertyMap) {
+        auto metaField = remapMetaDataField(field);
+        auto value = (metaField != M_MAX) ? getValueOrDefault(meta, MetadataHandler::getMetaFieldName(metaField)) : getValueOrDefault(auxData, field);
+        if (!value.empty()) {
+            addField(result, tag, value);
+        }
+    }
+}
+
+std::string UpnpXMLBuilder::printXml(const pugi::xml_node& entry, const char* indent, int flags)
+{
+    std::ostringstream buf;
+    entry.print(buf, indent, flags);
+    return buf.str();
+}
+
 void UpnpXMLBuilder::addField(pugi::xml_node& entry, const std::string& key, const std::string& val)
 {
     // e.g. used for M_ALBUMARTIST
     // name@attr[val] => <name attr="val">
-    std::size_t i, j;
-    if (((i = key.find('@')) != std::string::npos)
-        && ((j = key.find('[', i + 1)) != std::string::npos)
-        && (key[key.length() - 1] == ']')) {
+    std::size_t i = key.find('@');
+    std::size_t j = key.find('[', i + 1);
+    if (i != std::string::npos
+        && j != std::string::npos
+        && key[key.length() - 1] == ']') {
         std::string attr_name = key.substr(i + 1, j - i - 1);
         std::string attr_value = key.substr(j + 1, key.length() - j - 2);
         std::string name = key.substr(0, i);
@@ -98,14 +132,16 @@ void UpnpXMLBuilder::renderObject(const std::shared_ptr<CdsObject>& obj, size_t
         tmp = tmp.substr(0, getValidUTF8CutPosition(tmp, stringLimit - 3));
         tmp = tmp + "...";
     }
-    result.append_child("dc:title").append_child(pugi::node_pcdata).set_value(tmp.c_str());
 
+    result.append_child("dc:title").append_child(pugi::node_pcdata).set_value(tmp.c_str());
     result.append_child("upnp:class").append_child(pugi::node_pcdata).set_value(obj->getClass().c_str());
 
+    auto auxData = obj->getAuxData();
+
     if (obj->isItem()) {
         auto item = std::static_pointer_cast<CdsItem>(obj);
 
-        if (quirks != nullptr)
+        if (quirks)
             quirks->restoreSamsungBookMarkedPosition(item, &result);
 
         auto meta = obj->getMetadata();
@@ -127,15 +163,14 @@ void UpnpXMLBuilder::renderObject(const std::shared_ptr<CdsObject>& obj, size_t
                 addField(result, key, val);
             }
         }
-        const auto titleProperties = config->getDictionaryOption(CFG_UPNP_TITLE_PROPERTIES);
-        for (auto&& [tag, field] : titleProperties) {
-            auto value = getValueOrDefault(meta, MetadataHandler::getMetaFieldName(remapMetaDataField(field)));
-            if (!value.empty()) {
-                addField(result, tag, value);
+        {
+            auto [url, artAdded] = renderItemImage(virtualURL, item);
+            if (artAdded) {
+                meta[MetadataHandler::getMetaFieldName(M_ALBUMARTURI)] = url;
             }
         }
-
-        addResources(item, &result);
+        addPropertyList(result, meta, auxData, CFG_UPNP_TITLE_PROPERTIES, CFG_UPNP_TITLE_NAMESPACES);
+        addResources(item, &result, quirks);
 
         result.set_name("item");
     } else if (obj->isContainer()) {
@@ -150,35 +185,22 @@ void UpnpXMLBuilder::renderObject(const std::shared_ptr<CdsObject>& obj, size_t
         log_debug("container is class: {}", upnp_class.c_str());
         auto meta = obj->getMetadata();
         if (upnp_class == UPNP_CLASS_MUSIC_ALBUM) {
-            const auto albumProperties = config->getDictionaryOption(CFG_UPNP_ALBUM_PROPERTIES);
-            for (auto&& [tag, field] : albumProperties) {
-                auto value = getValueOrDefault(meta, MetadataHandler::getMetaFieldName(remapMetaDataField(field)));
-                if (!value.empty()) {
-                    addField(result, tag, value);
-                }
-            }
+            addPropertyList(result, meta, auxData, CFG_UPNP_ALBUM_PROPERTIES, CFG_UPNP_ALBUM_NAMESPACES);
         } else if (upnp_class == UPNP_CLASS_MUSIC_ARTIST) {
-            const auto artistProperties = config->getDictionaryOption(CFG_UPNP_ARTIST_PROPERTIES);
-            for (auto&& [tag, field] : artistProperties) {
-                auto value = getValueOrDefault(meta, MetadataHandler::getMetaFieldName(remapMetaDataField(field)));
-                if (!value.empty()) {
-                    addField(result, tag, value);
-                }
-            }
+            addPropertyList(result, meta, auxData, CFG_UPNP_ARTIST_PROPERTIES, CFG_UPNP_ARTIST_NAMESPACES);
+        } else if (upnp_class == UPNP_CLASS_MUSIC_GENRE) {
+            addPropertyList(result, meta, auxData, CFG_UPNP_GENRE_PROPERTIES, CFG_UPNP_GENRE_NAMESPACES);
+        } else if (upnp_class == UPNP_CLASS_PLAYLIST_CONTAINER) {
+            addPropertyList(result, meta, auxData, CFG_UPNP_PLAYLIST_PROPERTIES, CFG_UPNP_PLAYLIST_NAMESPACES);
         }
-        if (upnp_class == UPNP_CLASS_MUSIC_ALBUM || upnp_class == UPNP_CLASS_MUSIC_ARTIST || upnp_class == UPNP_CLASS_CONTAINER) {
-            std::string url;
-            bool artAdded = renderContainerImage(virtualURL, cont, url);
+        if (upnp_class == UPNP_CLASS_MUSIC_ALBUM || upnp_class == UPNP_CLASS_MUSIC_ARTIST || upnp_class == UPNP_CLASS_CONTAINER || upnp_class == UPNP_CLASS_PLAYLIST_CONTAINER) {
+            auto [url, artAdded] = renderContainerImage(virtualURL, cont);
             if (artAdded) {
                 result.append_child(MetadataHandler::getMetaFieldName(M_ALBUMARTURI).c_str()).append_child(pugi::node_pcdata).set_value(url.c_str());
             }
         }
     }
-#ifdef DEBUG_UPNP
-    std::ostringstream osr;
-    result.print(osr, "  ");
-    log_debug("Rendered DIDL: {}", osr.str());
-#endif
+    log_debug("Rendered DIDL: {}", printXml(result, "  "));
 }
 
 std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::createEventPropertySet()
@@ -203,6 +225,7 @@ std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::renderDeviceDescription()
 
     auto root = doc->append_child("root");
     root.append_attribute("xmlns") = UPNP_DESC_DEVICE_NAMESPACE;
+    root.append_attribute(UPNP_XML_SEC_NAMESPACE_ATTR) = UPNP_XML_SEC_NAMESPACE;
 
     auto specVersion = root.append_child("specVersion");
     specVersion.append_child("major").append_child(pugi::node_pcdata).set_value(UPNP_DESC_SPEC_VERSION_MAJOR);
@@ -211,48 +234,49 @@ std::unique_ptr<pugi::xml_document> UpnpXMLBuilder::renderDeviceDescription()
     auto device = root.append_child("device");
 
     auto dlnaDoc = device.append_child("dlna:X_DLNADOC");
-    dlnaDoc.append_attribute("xmlns:dlna") = "urn:schemas-dlna-org:device-1-0";
+    dlnaDoc.append_attribute(UPNP_XML_DLNA_NAMESPACE_ATTR) = UPNP_XML_DLNA_NAMESPACE;
     dlnaDoc.append_child(pugi::node_pcdata).set_value("DMS-1.50");
     // dlnaDoc.append_child(pugi::node_pcdata).set_value("M-DMS-1.50");
 
-    device.append_child("deviceType").append_child(pugi::node_pcdata).set_value(UPNP_DESC_DEVICE_TYPE);
-    if (presentationURL.empty())
-        device.append_child("presentationURL").append_child(pugi::node_pcdata).set_value("/");
-    else
-        device.append_child("presentationURL").append_child(pugi::node_pcdata).set_value(presentationURL.c_str());
-
-    constexpr std::array<std::pair<const char*, config_option_t>, 9> deviceProperties { {
-        // { "deviceType", {} },
-        // { "presentationURL", {} },
-        { "friendlyName", CFG_SERVER_NAME },
-        { "manufacturer", CFG_SERVER_MANUFACTURER },
-        { "manufacturerURL", CFG_SERVER_MANUFACTURER_URL },
-        { "modelDescription", CFG_SERVER_MODEL_DESCRIPTION },
-        { "modelName", CFG_SERVER_MODEL_NAME },
-        { "modelNumber", CFG_SERVER_MODEL_NUMBER },
-        { "modelURL", CFG_SERVER_MODEL_URL },
-        { "serialNumber", CFG_SERVER_SERIAL_NUMBER },
-        { "UDN", CFG_SERVER_UDN },
-    } };
+    constexpr auto deviceProperties = std::array {
+        std::pair("friendlyName", CFG_SERVER_NAME),
+        std::pair("manufacturer", CFG_SERVER_MANUFACTURER),
+        std::pair("manufacturerURL", CFG_SERVER_MANUFACTURER_URL),
+        std::pair("modelDescription", CFG_SERVER_MODEL_DESCRIPTION),
+        std::pair("modelName", CFG_SERVER_MODEL_NAME),
+        std::pair("modelNumber", CFG_SERVER_MODEL_NUMBER),
+        std::pair("modelURL", CFG_SERVER_MODEL_URL),
+        std::pair("serialNumber", CFG_SERVER_SERIAL_NUMBER),
+        std::pair("UDN", CFG_SERVER_UDN),
+    };
     for (auto&& [tag, field] : deviceProperties) {
         device.append_child(tag).append_child(pugi::node_pcdata).set_value(config->getOption(field).c_str());
     }
+    const auto deviceStringProperties = std::array {
+        std::pair("deviceType", UPNP_DESC_DEVICE_TYPE),
+        std::pair("presentationURL", presentationURL.empty() ? "/" : presentationURL.c_str()),
+        std::pair("sec:ProductCap", UPNP_DESC_PRODUCT_CAPS),
+        std::pair("sec:X_ProductCap", UPNP_DESC_PRODUCT_CAPS), // used by SAMSUNG
+    };
+    for (auto&& [tag, value] : deviceStringProperties) {
+        device.append_child(tag).append_child(pugi::node_pcdata).set_value(value);
+    }
 
     // add icons
     {
         auto iconList = device.append_child("iconList");
 
-        constexpr std::array<std::pair<const char*, const char*>, 3> iconDims { {
-            { "120", "24" },
-            { "48", "24" },
-            { "32", "8" },
-        } };
+        constexpr auto iconDims = std::array {
+            std::pair("120", "24"),
+            std::pair("48", "24"),
+            std::pair("32", "8"),
+        };
 
-        constexpr std::array<std::pair<const char*, const char*>, 3> iconTypes { {
-            { UPNP_DESC_ICON_PNG_MIMETYPE, ".png" },
-            { UPNP_DESC_ICON_BMP_MIMETYPE, ".bmp" },
-            { UPNP_DESC_ICON_JPG_MIMETYPE, ".jpg" },
-        } };
+        constexpr auto iconTypes = std::array {
+            std::pair(UPNP_DESC_ICON_PNG_MIMETYPE, ".png"),
+            std::pair(UPNP_DESC_ICON_BMP_MIMETYPE, ".bmp"),
+            std::pair(UPNP_DESC_ICON_JPG_MIMETYPE, ".jpg"),
+        };
 
         for (auto&& [dim, depth] : iconDims) {
             for (auto&& [mimetype, ext] : iconTypes) {
@@ -312,32 +336,29 @@ void UpnpXMLBuilder::renderResource(const std::string& URL, const std::map<std::
 
 std::unique_ptr<UpnpXMLBuilder::PathBase> UpnpXMLBuilder::getPathBase(const std::shared_ptr<CdsItem>& item, bool forceLocal)
 {
-    auto pathBase = std::make_unique<PathBase>();
     /// \todo resource options must be read from configuration files
 
     std::map<std::string, std::string> dict;
     dict[URL_OBJECT_ID] = fmt::to_string(item->getID());
 
-    pathBase->addResID = false;
     /// \todo move this down into the "for" loop and create different urls
     /// for each resource once the io handlers are ready    int objectType = ;
     if (item->isExternalItem()) {
         if (!item->getFlag(OBJECT_FLAG_PROXY_URL) && (!forceLocal)) {
-            pathBase->pathBase = item->getLocation();
-            return pathBase;
+            return std::make_unique<PathBase>(PathBase { item->getLocation(), false });
         }
 
         if ((item->getFlag(OBJECT_FLAG_ONLINE_SERVICE) && item->getFlag(OBJECT_FLAG_PROXY_URL)) || forceLocal) {
-            pathBase->pathBase = RequestHandler::joinUrl({ CONTENT_ONLINE_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
-            pathBase->addResID = true;
-            return pathBase;
+            auto path = RequestHandler::joinUrl({ CONTENT_ONLINE_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
+            return std::make_unique<PathBase>(PathBase { path, true });
         }
     }
-    pathBase->pathBase = RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
-    pathBase->addResID = true;
-    return pathBase;
+    auto path = RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID }, true);
+    return std::make_unique<PathBase>(PathBase { path, true });
 }
 
+/// \brief build path for first resource from item
+/// depending on the item type it returns the url to the media
 std::string UpnpXMLBuilder::getFirstResourcePath(const std::shared_ptr<CdsItem>& item)
 {
     auto urlBase = getPathBase(item);
@@ -356,7 +377,6 @@ std::string UpnpXMLBuilder::getFirstResourcePath(const std::shared_ptr<CdsItem>&
 
 std::string UpnpXMLBuilder::getArtworkUrl(const std::shared_ptr<CdsItem>& item) const
 {
-    // FIXME: This is temporary until we do artwork properly.
     log_debug("Building Art url for {}", item->getID());
 
     auto urlBase = getPathBase(item);
@@ -366,10 +386,8 @@ std::string UpnpXMLBuilder::getArtworkUrl(const std::shared_ptr<CdsItem>& item)
     return virtualURL + urlBase->pathBase;
 }
 
-bool UpnpXMLBuilder::renderContainerImage(const std::string& virtualURL, const std::shared_ptr<CdsContainer>& cont, std::string& url)
+std::pair<std::string, bool> UpnpXMLBuilder::renderContainerImage(const std::string& virtualURL, const std::shared_ptr<CdsContainer>& cont)
 {
-    bool artAdded = false;
-    int resIdx = 0;
     for (auto&& res : cont->getResources()) {
         if (res->isMetaResource(ID3_ALBUM_ART)) {
             auto&& resFile = res->getAttribute(R_RESOURCE_FILE);
@@ -381,10 +399,8 @@ bool UpnpXMLBuilder::renderContainerImage(const std::string& virtualURL, const s
 
                 auto res_params = res->getParameters();
                 res_params[RESOURCE_HANDLER] = fmt::to_string(res->getHandlerType());
-                url.assign(virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, fmt::to_string(resIdx), dictEncodeSimple(res_params) }));
-
-                artAdded = true;
-                break;
+                auto url = virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, fmt::to_string(res->getResId()), dictEncodeSimple(res_params) });
+                return std::pair(url, true);
             }
 
             if (!resObj.empty()) {
@@ -392,93 +408,94 @@ bool UpnpXMLBuilder::renderContainerImage(const std::string& virtualURL, const s
                 dict[URL_OBJECT_ID] = resObj;
 
                 auto res_params = res->getParameters();
-                url.assign(virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, res->getAttribute(R_FANART_RES_ID), dictEncodeSimple(res_params) }));
-
-                artAdded = true;
-                break;
+                auto url = virtualURL + RequestHandler::joinUrl({ CONTENT_MEDIA_HANDLER, dictEncodeSimple(dict), URL_RESOURCE_ID, res->getAttribute(R_FANART_RES_ID), dictEncodeSimple(res_params) });
+                return std::pair(url, true);
             }
         }
-        resIdx++;
     }
-    return artAdded;
+    return {};
 }
 
-bool UpnpXMLBuilder::renderItemImage(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, std::string& url)
+std::string UpnpXMLBuilder::renderOneResource(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, const std::shared_ptr<CdsResource>& res)
 {
-    bool artAdded = false;
+    auto&& res_params = res->getParameters();
     auto urlBase = getPathBase(item);
-    int realCount = 0;
-    for (auto&& res : item->getResources()) {
-        if (res->isMetaResource(ID3_ALBUM_ART) //
-            || (res->getHandlerType() == CH_LIBEXIF && res->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) //
-            || (res->getHandlerType() == CH_FFTH && res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL) //
-        ) {
-            auto res_attrs = res->getAttributes();
-            auto res_params = res->getParameters();
-            if (urlBase->addResID) {
-                url = fmt::format("{}{}{}{}", virtualURL.c_str(), urlBase->pathBase.c_str(), realCount, _URL_PARAM_SEPARATOR);
-            } else
-                url = virtualURL + urlBase->pathBase;
+    std::string url;
+    if (urlBase->addResID) {
+        url = fmt::format("{}{}{}{}", virtualURL.c_str(), urlBase->pathBase.c_str(), res->getResId(), _URL_PARAM_SEPARATOR);
+    } else
+        url = virtualURL + urlBase->pathBase;
 
-            if (!res_params.empty()) {
-                url.append(dictEncodeSimple(res_params));
-            }
-            artAdded = true;
-            break;
-        }
-        realCount++;
+    if (!res_params.empty()) {
+        url.append(dictEncodeSimple(res_params));
     }
-    return artAdded;
+    return url;
 }
 
-bool UpnpXMLBuilder::renderSubtitle(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item, std::string& url)
+std::pair<std::string, bool> UpnpXMLBuilder::renderItemImage(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item)
 {
-    bool srtAdded = false;
-    auto urlBase = getPathBase(item);
-    int realCount = 0;
-    for (auto&& res : item->getResources()) {
-        if (res->isMetaResource(VIDEO_SUB)) {
-            auto res_attrs = res->getAttributes();
-            auto res_params = res->getParameters();
-            if (urlBase->addResID) {
-                url = fmt::format("{}{}{}{}", virtualURL.c_str(), urlBase->pathBase, realCount, _URL_PARAM_SEPARATOR);
-            } else
-                url = virtualURL + urlBase->pathBase;
-
-            if (!res_params.empty()) {
-                url.append(dictEncodeSimple(res_params));
-            }
-            srtAdded = true;
-            break;
-        }
-        realCount++;
+    auto orderedResources = getOrderedResources(item);
+    auto resFound = std::find_if(orderedResources.begin(), orderedResources.end(),
+        [](auto&& res) { return res->isMetaResource(ID3_ALBUM_ART) //
+                             || (res->getHandlerType() == CH_LIBEXIF && res->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) //
+                             || (res->getHandlerType() == CH_FFTH && res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL); });
+    if (resFound != orderedResources.end()) {
+        return std::pair(renderOneResource(virtualURL, item, *resFound), true);
     }
-    return srtAdded;
+
+    return {};
 }
 
-std::string UpnpXMLBuilder::renderExtension(const std::string& contentType, const std::string& location)
+std::pair<std::string, bool> UpnpXMLBuilder::renderSubtitle(const std::string& virtualURL, const std::shared_ptr<CdsItem>& item)
 {
-    std::string ext = RequestHandler::joinUrl({ URL_FILE_EXTENSION, "file" });
+    auto resources = item->getResources();
+    auto resFound = std::find_if(resources.begin(), resources.end(),
+        [](auto&& res) { return res->isMetaResource(VIDEO_SUB, CH_SUBTITLE); });
+    if (resFound != resources.end()) {
+        auto url = renderOneResource(virtualURL, item, *resFound) + renderExtension("", (*resFound)->getAttribute(R_RESOURCE_FILE));
+        return std::pair(url, true);
+    }
+    return {};
+}
+
+std::string UpnpXMLBuilder::renderExtension(const std::string& contentType, const fs::path& location)
+{
+    auto&& ext = RequestHandler::joinUrl({ URL_FILE_EXTENSION, "file" });
 
     if (!contentType.empty() && (contentType != CONTENT_TYPE_PLAYLIST)) {
         return fmt::format("{}.{}", ext, contentType);
     }
 
-    if (!location.empty()) {
-        size_t dot = location.rfind('.');
-        if (dot != std::string::npos) {
-            std::string extension = location.substr(dot);
-            // make sure that the extension does not contain the separator character
-            if (extension.find(URL_PARAM_SEPARATOR) == std::string::npos) {
-                return ext + extension;
-            }
-        }
+    if (!location.empty() && location.has_extension()) {
+        // make sure that the filename does not contain the separator character
+        auto&& filename = urlEscape(location.filename().stem().string());
+        auto&& extension = location.filename().extension().string();
+        return fmt::format("{}.{}{}", ext, (filename), extension);
     }
 
     return "";
 }
 
-void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent)
+std::vector<std::shared_ptr<CdsResource>> UpnpXMLBuilder::getOrderedResources(const std::shared_ptr<CdsItem>& item)
+{
+    // Order resources according to index defined by orderedHandler
+    std::vector<std::shared_ptr<CdsResource>> orderedResources;
+    auto&& resources = item->getResources();
+    for (auto&& oh : orderedHandler) {
+        std::for_each(resources.begin(), resources.end(), [&](auto res) { if (oh == res->getHandlerType()) orderedResources.push_back(res); });
+    }
+
+    // Append resources not listed in orderedHandler
+    for (auto&& res : resources) {
+        auto ch = res->getHandlerType();
+        if (std::none_of(orderedHandler.begin(), orderedHandler.end(), [ch](auto&& entry) { return ch == entry; })) {
+            orderedResources.push_back(res);
+        }
+    }
+    return orderedResources;
+}
+
+void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xml_node* parent, const std::shared_ptr<Quirks>& quirks)
 {
     auto urlBase = getPathBase(item);
     bool skipURL = (item->isExternalItem() && !item->getFlag(OBJECT_FLAG_PROXY_URL));
@@ -488,9 +505,8 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
 
     // this will be used to count only the "real" resources, omitting the
     // transcoded ones
-    int realCount = 0;
     bool hide_original_resource = false;
-    size_t original_resource = 0;
+    int original_resource = -1;
 
     std::unique_ptr<PathBase> urlBase_tr;
 
@@ -498,23 +514,25 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
     // config manager we should use that setting
     //
     // TODO: allow transcoding for URLs
+    auto orderedResources = getOrderedResources(item);
 
     // now get the profile
     auto tlist = config->getTranscodingProfileListOption(CFG_TRANSCODING_PROFILE_LIST);
     auto tp_mt = tlist->get(item->getMimeType());
-    if (tp_mt != nullptr) {
+    if (tp_mt) {
         for (auto&& [key, tp] : *tp_mt) {
-            if (tp == nullptr)
+            if (!tp)
                 throw_std_runtime_error("Invalid profile encountered");
-
+            // check for client profile prop and filter if no match
+            if (quirks && tp->getClientFlags() > 0 && quirks->checkFlags(tp->getClientFlags()) == 0)
+                continue;
             std::string ct = getValueOrDefault(mappings, item->getMimeType());
             if (ct == CONTENT_TYPE_OGG) {
                 if (((item->getFlag(OBJECT_FLAG_OGG_THEORA)) && (!tp->isTheora())) || (!item->getFlag(OBJECT_FLAG_OGG_THEORA) && (tp->isTheora()))) {
                     continue;
                 }
-            }
-            // check user fourcc settings
-            else if (ct == CONTENT_TYPE_AVI) {
+            } else if (ct == CONTENT_TYPE_AVI) {
+                // check user fourcc settings
                 avi_fourcc_listmode_t fcc_mode = tp->getAVIFourCCListMode();
 
                 std::vector<std::string> fcc_list = tp->getAVIFourCCList();
@@ -530,10 +548,9 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
                         // fourcc can not match anything we will skip the item
                         if (fcc_mode == FCC_Process)
                             continue;
-                    }
-                    // we have the current and hopefully valid fcc string
-                    // let's have a look if it matches the list
-                    else {
+                    } else {
+                        // we have the current and hopefully valid fcc string
+                        // let's have a look if it matches the list
                         bool fcc_match = std::find(fcc_list.begin(), fcc_list.end(), current_fcc) != fcc_list.end();
                         if (!fcc_match && (fcc_mode == FCC_Process))
                             continue;
@@ -545,11 +562,11 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             }
 
             auto t_res = std::make_shared<CdsResource>(CH_TRANSCODE);
+            t_res->setResId(std::numeric_limits<int>::max());
             t_res->addParameter(URL_PARAM_TRANSCODE_PROFILE_NAME, tp->getName());
             // after transcoding resource was added we can not rely on
             // index 0, so we will make sure the ogg option is there
-            t_res->addOption(CONTENT_TYPE_OGG,
-                item->getResource(0)->getOption(CONTENT_TYPE_OGG));
+            t_res->addOption(CONTENT_TYPE_OGG, item->getResource(0)->getOption(CONTENT_TYPE_OGG));
             t_res->addParameter(URL_PARAM_TRANSCODE, URL_VALUE_TRANSCODE);
 
             std::string targetMimeType = tp->getTargetMimeType();
@@ -597,24 +614,22 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
                 hide_original_resource = true;
 
             if (tp->firstResource()) {
-                item->insertResource(0, t_res);
-                original_resource++;
+                orderedResources.insert(orderedResources.begin(), std::move(t_res));
+                original_resource = 0;
             } else
-                item->addResource(t_res);
+                orderedResources.push_back(std::move(t_res));
         }
 
         if (skipURL)
             urlBase_tr = getPathBase(item, true);
     }
 
-    size_t resCount = item->getResourceCount();
-    for (size_t i = 0; i < resCount; i++) {
-
+    bool isFirstSub = true;
+    for (auto&& res : orderedResources) {
         /// \todo what if the resource has a different mimetype than the item??
         /*        std::string mimeType = item->getMimeType();
                   if (mimeType.empty()) mimeType = DEFAULT_MIMETYPE; */
 
-        auto res = item->getResource(i);
         auto res_attrs = res->getAttributes();
         auto res_params = res->getParameters();
         std::string protocolInfo = getValueOrDefault(res_attrs, MetadataHandler::getResAttrName(R_PROTOCOLINFO));
@@ -646,16 +661,14 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
         bool transcoded = (getValueOrDefault(res_params, URL_PARAM_TRANSCODE) == URL_VALUE_TRANSCODE);
         if (!transcoded) {
             if (urlBase->addResID) {
-                url = fmt::format("{}{}", urlBase->pathBase, realCount);
+                url = fmt::format("{}{}", urlBase->pathBase, res->getResId());
             } else
                 url = urlBase->pathBase;
-
-            realCount++;
         } else {
             if (!skipURL)
                 url = urlBase->pathBase + URL_VALUE_TRANSCODE_NO_RES_ID;
             else {
-                assert(urlBase_tr != nullptr);
+                assert(urlBase_tr);
                 url = urlBase_tr->pathBase + URL_VALUE_TRANSCODE_NO_RES_ID;
             }
         }
@@ -667,7 +680,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
         // ok this really sucks, I guess another rewrite of the resource manager
         // is necessary
         int handlerType = res->getHandlerType();
-        if ((i > 0) && (handlerType == CH_EXTURL) && ((res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL) || (res->getOption(RESOURCE_CONTENT_TYPE) == ID3_ALBUM_ART))) {
+        if ((res->getResId() > 0) && (handlerType == CH_EXTURL) && ((res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL) || (res->getOption(RESOURCE_CONTENT_TYPE) == ID3_ALBUM_ART))) {
             url = res->getOption(RESOURCE_OPTION_URL);
             if (url.empty())
                 throw_std_runtime_error("missing thumbnail URL");
@@ -675,8 +688,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             isExtThumbnail = true;
         }
 
-        /// FIXME: currently resource is misused for album art
-
+        // resource is used to point to album art
         // only add upnp:AlbumArtURI if we have an AA, skip the resource
         if (res->isMetaResource(ID3_ALBUM_ART) //
             || (res->getHandlerType() == CH_LIBEXIF && res->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) //
@@ -687,17 +699,21 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
 
             /// \todo clean this up, make sure to check the mimetype and
             /// provide the profile correctly
-            aa.append_attribute("xmlns:dlna") = "urn:schemas-dlna-org:metadata-1-0";
+            aa.append_attribute(UPNP_XML_DLNA_NAMESPACE_ATTR) = UPNP_XML_DLNA_METADATA_NAMESPACE;
             aa.append_attribute("dlna:profileID") = "JPEG_TN";
-            if (res->isMetaResource(ID3_ALBUM_ART))
+            if (res->isMetaResource(ID3_ALBUM_ART)) {
                 continue;
+            }
         }
-        if (res->isMetaResource(VIDEO_SUB)) {
+        if (isFirstSub && res->isMetaResource(VIDEO_SUB, CH_SUBTITLE)) {
             auto vs = parent->append_child("sec:CaptionInfoEx");
-            vs.append_child(pugi::node_pcdata).set_value((virtualURL + url).c_str());
+            auto subUrl = url;
+            subUrl.append(renderExtension("", res->getAttribute(R_RESOURCE_FILE)));
+            vs.append_child(pugi::node_pcdata).set_value((virtualURL + subUrl).c_str());
             vs.append_attribute("sec:type") = res->getAttribute(R_TYPE).c_str();
+            vs.append_attribute(MetadataHandler::getResAttrName(R_LANGUAGE).c_str()) = res->getAttribute(R_LANGUAGE).c_str();
             vs.append_attribute(MetadataHandler::getResAttrName(R_PROTOCOLINFO).c_str()) = protocolInfo.c_str();
-            continue;
+            isFirstSub = false;
         }
 
         if (!isExtThumbnail) {
@@ -706,7 +722,10 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             // content type here and that we will not limit ourselves to the
             // first resource
             if (!skipURL) {
-                url.append(renderExtension(contentType, transcoded ? "" : item->getLocation()));
+                auto ext = renderExtension("", res->getAttribute(R_RESOURCE_FILE)); // try extension from resource file
+                if (ext.empty())
+                    ext = renderExtension(contentType, transcoded ? "" : item->getLocation());
+                url.append(ext);
             }
         }
 
@@ -715,7 +734,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             std::string resolution = getValueOrDefault(res_attrs, MetadataHandler::getResAttrName(R_RESOLUTION));
             int x;
             int y;
-            if ((i > 0) && !resolution.empty() && checkResolution(resolution, &x, &y)) {
+            if ((res->getResId() > 0) && !resolution.empty() && checkResolution(resolution, &x, &y)) {
                 if ((((res->getHandlerType() == CH_LIBEXIF) && (res->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL)) || (res->getOption(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) || (res->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL)) && (x <= 160) && (y <= 160))
                     extend = fmt::format("{}={};", UPNP_DLNA_PROFILE, UPNP_DLNA_PROFILE_JPEG_TN);
                 else if ((x <= 640) && (y <= 420))
@@ -727,9 +746,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             }
         } else {
             /* handle audio/video content */
-            extend = getDLNAprofileString(contentType);
-            if (!extend.empty())
-                extend.append(";");
+            extend = getDLNAprofileString(config, contentType);
         }
 
         // we do not support seeking at all, so 00
@@ -753,7 +770,7 @@ void UpnpXMLBuilder::addResources(const std::shared_ptr<CdsItem>& item, pugi::xm
             url.insert(0, virtualURL);
         }
 
-        if (!hide_original_resource || transcoded || (hide_original_resource && (original_resource != i)))
+        if (!hide_original_resource || transcoded || (hide_original_resource && (original_resource != res->getResId())))
             renderResource(url, res_attrs, parent);
     }
 }
