@@ -70,26 +70,17 @@ void URLRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     if (!tr_profile.empty()) {
         auto tp = config->getTranscodingProfileListOption(CFG_TRANSCODING_PROFILE_LIST)
                       ->getByName(tr_profile);
-        if (tp == nullptr)
+        if (!tp)
             throw_std_runtime_error("Transcoding requested but no profile matching the name {} found", tr_profile.c_str());
 
         mimeType = tp->getTargetMimeType();
         UpnpFileInfo_set_FileLength(info, -1);
     } else {
-        std::string url;
-
 #ifdef ONLINE_SERVICES
-        if (item->getFlag(OBJECT_FLAG_ONLINE_SERVICE)) {
-            /// \todo write a helper class that will handle various online
-            /// services
-            auto helper = std::make_unique<OnlineServiceHelper>();
-            url = helper->resolveURL(item);
-        } else
+        std::string url = item->getFlag(OBJECT_FLAG_ONLINE_SERVICE) ? OnlineServiceHelper::resolveURL(item) : item->getLocation().string();
+#else
+        std::string url = item->getLocation().string();
 #endif
-        {
-            url = item->getLocation();
-        }
-
         log_debug("Online content url: {}", url.c_str());
         try {
             auto st = URL::getInfo(url);
@@ -114,10 +105,10 @@ void URLRequestHandler::getInfo(const char* filename, UpnpFileInfo* info)
     //            ixmlCloneDOMString(header.c_str()));
     //    }
 
-#if defined(USING_NPUPNP)
-    UpnpFileInfo_set_ContentType(info, mimeType);
+#ifdef USING_NPUPNP
+    info->content_type = std::move(mimeType);
 #else
-    UpnpFileInfo_set_ContentType(info, ixmlCloneDOMString(mimeType.c_str()));
+    UpnpFileInfo_set_ContentType(info, mimeType.c_str());
 #endif
     log_debug("web_get_info(): end");
 
@@ -140,25 +131,18 @@ std::unique_ptr<IOHandler> URLRequestHandler::open(const char* filename, enum Up
     }
 
     auto item = std::static_pointer_cast<CdsItemExternalURL>(obj);
-
-    std::string url;
 #ifdef ONLINE_SERVICES
-    if (item->getFlag(OBJECT_FLAG_ONLINE_SERVICE)) {
-        auto helper = std::make_unique<OnlineServiceHelper>();
-        url = helper->resolveURL(item);
-    } else
+    std::string url = item->getFlag(OBJECT_FLAG_ONLINE_SERVICE) ? OnlineServiceHelper::resolveURL(item) : item->getLocation().string();
+#else
+    std::string url = item->getLocation().string();
 #endif
-    {
-        url = item->getLocation();
-    }
-
     log_debug("Online content url: {}", url.c_str());
 
     std::string tr_profile = getValueOrDefault(params, URL_PARAM_TRANSCODE_PROFILE_NAME);
     if (!tr_profile.empty()) {
         auto tp = config->getTranscodingProfileListOption(CFG_TRANSCODING_PROFILE_LIST)
                       ->getByName(tr_profile);
-        if (tp == nullptr)
+        if (!tp)
             throw_std_runtime_error("Transcoding of file {} but no profile matching the name {} found", url.c_str(), tr_profile.c_str());
 
         auto tr_d = std::make_unique<TranscodeDispatcher>(content);
