@@ -23,15 +23,16 @@ enum task_owner_t {
 class GenericTask {
 protected:
     std::string description;
-    task_type_t taskType;
+    task_type_t taskType { Invalid };
     task_owner_t taskOwner;
-    unsigned int parentTaskID;
-    unsigned int taskID;
-    bool valid;
-    bool cancellable;
+    unsigned int parentTaskID {};
+    unsigned int taskID {};
+    bool valid { true };
+    bool cancellable { true };
 
 public:
     explicit GenericTask(task_owner_t taskOwner);
+    virtual ~GenericTask() = default;
     virtual void run() = 0;
     void setDescription(const std::string& description) { this->description = description; }
     std::string getDescription() const { return description; }
@@ -44,8 +45,6 @@ public:
     bool isCancellable() const { return cancellable; }
     void invalidate() { valid = false; }
     task_owner_t getOwner() const { return taskOwner; }
-
-    virtual ~GenericTask() = default;
 };
 
 #endif //__GENERIC_TASK_H__
