@@ -58,13 +58,13 @@ public:
     int getStatus() override = 0;
 
 protected:
-    bool threadShutdown { false };
+    bool threadShutdown {};
     /// \brief if the thread is currently running
-    bool threadRunning;
+    bool threadRunning {};
 
     std::condition_variable cond;
     std::mutex mutex;
-    pthread_t thread { 0 };
+    pthread_t thread {};
 
     /// \brief abstract thread method, which needs to be overridden
     virtual void threadProc() = 0;
