@@ -82,13 +82,12 @@ struct ClientCacheEntry {
 class Clients {
 public:
     explicit Clients(const std::shared_ptr<Config>& config);
-    virtual ~Clients() = default;
 
     // always return something, 'Unknown' if we do not know better
     void getInfo(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo** ppInfo);
 
     void addClientByDiscovery(const struct sockaddr_storage* addr, const std::string& userAgent, const std::string& descLocation);
-    std::shared_ptr<std::vector<ClientCacheEntry>> getClientList() { return cache; }
+    std::shared_ptr<std::vector<ClientCacheEntry>> getClientList() const { return cache; }
 
 private:
     bool getInfoByAddr(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
@@ -97,9 +96,8 @@ private:
     bool getInfoByCache(const struct sockaddr_storage* addr, const ClientInfo** ppInfo);
     void updateCache(const struct sockaddr_storage* addr, const std::string& userAgent, const ClientInfo* pInfo);
 
-    static bool downloadDescription(const std::string& location, std::unique_ptr<pugi::xml_document>& xml);
+    static bool downloadDescription(const std::string& location, std::unique_ptr<pugi::xml_document> xml);
 
-private:
     std::mutex mutex;
     using AutoLock = std::lock_guard<std::mutex>;
     std::shared_ptr<std::vector<ClientCacheEntry>> cache;
