@@ -63,24 +63,17 @@ void Headers::addHeader(const std::string& key, const std::string& value)
         return;
     }
 
-    if (headers == nullptr) {
+    if (!headers) {
         headers = std::make_unique<std::map<std::string, std::string>>();
     }
 
     log_debug("Adding header: '{}: {}'", cleanKey.c_str(), cleanValue.c_str());
-    headers->insert(std::make_pair(cleanKey, cleanValue));
+    headers->insert(std::pair(cleanKey, cleanValue));
 }
 
 std::string Headers::formatHeader(const std::pair<std::string, std::string>& header, bool crlf)
 {
-    std::string headerValue;
-    headerValue += header.first;
-    headerValue += ": ";
-    headerValue += header.second;
-    if (crlf)
-        headerValue += "\r\n";
-
-    return headerValue;
+    return fmt::format("{}: {}{}", header.first, header.second, (crlf) ? "\r\n" : "");
 }
 
 std::pair<std::string, std::string> Headers::parseHeader(const std::string& header)
@@ -95,12 +88,12 @@ std::pair<std::string, std::string> Headers::parseHeader(const std::string& head
 
     trimStringInPlace(first);
     trimStringInPlace(second);
-    return std::make_pair(first, second);
+    return std::pair(first, second);
 }
 
 void Headers::writeHeaders(UpnpFileInfo* fileInfo) const
 {
-    if (headers == nullptr)
+    if (!headers)
         return;
 
 #if defined(USING_NPUPNP)
@@ -120,7 +113,7 @@ std::unique_ptr<std::map<std::string, std::string>> Headers::readHeaders(UpnpFil
 #if defined(USING_NPUPNP)
     return std::make_unique<std::map<std::string, std::string>>(fileInfo->request_headers);
 #else
-    auto ret = std::make_unique<std::map<std::string, std::string>>();
+    std::map<std::string, std::string> ret;
 
     auto head = const_cast<UpnpListHead*>(UpnpFileInfo_get_ExtraHeadersList(fileInfo));
     UpnpListIter pos;
@@ -128,9 +121,9 @@ std::unique_ptr<std::map<std::string, std::string>> Headers::readHeaders(UpnpFil
         auto extra = reinterpret_cast<UpnpExtraHeaders*>(pos);
         std::string header = UpnpExtraHeaders_get_resp(extra);
         auto add = parseHeader(header);
-        ret->insert(add);
+        ret.insert(add);
     }
 
-    return ret;
+    return std::make_unique<std::map<std::string, std::string>>(std::move(ret));
 #endif
 }
