@@ -50,7 +50,7 @@ void web::addObject::addContainer(int parentID)
     content->addContainer(parentID, param("title"), param("class"));
 }
 
-std::shared_ptr<CdsObject> web::addObject::addItem(int parentID, std::shared_ptr<CdsItem> item)
+std::shared_ptr<CdsObject> web::addObject::addItem(int parentID, const std::shared_ptr<CdsItem>& item)
 {
     item->setParentID(parentID);
 
@@ -70,10 +70,10 @@ std::shared_ptr<CdsObject> web::addObject::addItem(int parentID, std::shared_ptr
 
     item->setFlag(OBJECT_FLAG_USE_RESOURCE_REF);
 
-    return std::move(item);
+    return item;
 }
 
-std::shared_ptr<CdsObject> web::addObject::addUrl(int parentID, std::shared_ptr<CdsItemExternalURL> item, bool addProtocol)
+std::shared_ptr<CdsObject> web::addObject::addUrl(int parentID, const std::shared_ptr<CdsItemExternalURL>& item, bool addProtocol)
 {
     std::string protocolInfo;
 
@@ -104,9 +104,9 @@ std::shared_ptr<CdsObject> web::addObject::addUrl(int parentID, std::shared_ptr<
 
     auto resource = std::make_shared<CdsResource>(CH_DEFAULT);
     resource->addAttribute(R_PROTOCOLINFO, protocolInfo);
-    item->addResource(resource);
+    item->addResource(move(resource));
 
-    return std::move(item);
+    return item;
 }
 
 void web::addObject::process()
@@ -124,7 +124,7 @@ void web::addObject::process()
 
     int parentID = intParam("parent_id", 0);
 
-    std::shared_ptr<CdsObject> obj = nullptr;
+    std::shared_ptr<CdsObject> obj;
 
     bool allow_fifo = false;
     std::error_code ec;
@@ -146,7 +146,7 @@ void web::addObject::process()
         throw_std_runtime_error("Unknown object type: {}", obj_type.c_str());
     }
 
-    if (obj != nullptr) {
+    if (obj) {
         obj->setVirtual(true);
         if (obj_type == STRING_OBJECT_TYPE_ITEM) {
             content->addVirtualItem(obj, allow_fifo);
