@@ -32,6 +32,7 @@
 #include "config/config_definition.h"
 #include "config/config_setup.h"
 #include "config/directory_tweak.h"
+#include "config/dynamic_content.h"
 #include "content/autoscan.h"
 #include "content/content_manager.h"
 #include "database/database.h"
@@ -44,7 +45,7 @@ web::configLoad::configLoad(std::shared_ptr<ContentManager> content)
     : WebRequestHandler(std::move(content))
 {
     try {
-        if (this->database != nullptr) {
+        if (this->database) {
             dbEntries = this->database->getConfigValues();
         } else {
             log_error("configLoad database missing");
@@ -58,7 +59,7 @@ void web::configLoad::addTypeMeta(pugi::xml_node& meta, const std::shared_ptr<Co
 {
     auto info = meta.append_child("item");
     info.append_attribute("item") = cs->getUniquePath().c_str();
-    info.append_attribute("id") = fmt::format("{}", cs->option).c_str();
+    info.append_attribute("id") = fmt::format("{:03d}", cs->option).c_str();
     info.append_attribute("type") = cs->getTypeString().c_str();
     info.append_attribute("value") = cs->getDefaultValue().c_str();
     info.append_attribute("help") = cs->getHelp();
@@ -68,24 +69,24 @@ void web::configLoad::createItem(pugi::xml_node& item, const std::string& name,
 {
     allItems[name] = &item;
     item.append_attribute("item") = name.c_str();
-    item.append_attribute("id") = fmt::format("{:02d}", id).c_str();
-    item.append_attribute("aid") = fmt::format("{:02d}", aid).c_str();
+    item.append_attribute("id") = fmt::format("{:03d}", id).c_str();
+    item.append_attribute("aid") = fmt::format("{:03d}", aid).c_str();
     if (std::any_of(dbEntries.begin(), dbEntries.end(), [&](auto&& s) { return s.item == name; })) {
         item.append_attribute("status") = "unchanged";
         item.append_attribute("source") = "database";
     } else {
-        item.append_attribute("status") = cs == nullptr || !cs->isDefaultValueUsed() ? "unchanged" : "default";
-        item.append_attribute("source") = cs == nullptr || !cs->isDefaultValueUsed() ? "config.xml" : "default";
+        item.append_attribute("status") = !cs || !cs->isDefaultValueUsed() ? "unchanged" : "default";
+        item.append_attribute("source") = !cs || !cs->isDefaultValueUsed() ? "config.xml" : "default";
     }
     item.append_attribute("origValue") = config->getOrigValue(name).c_str();
-    item.append_attribute("defaultValue") = cs != nullptr ? cs->getDefaultValue().c_str() : "";
+    item.append_attribute("defaultValue") = cs ? cs->getDefaultValue().c_str() : "";
 }
 
 template <typename T>
 void web::configLoad::setValue(pugi::xml_node& item, const T& value)
 {
     static_assert(fmt::has_formatter<T, fmt::format_context>::value, "T must be formattable");
-    item.append_attribute("value") = fmt::format("{}", value).c_str();
+    item.append_attribute("value") = fmt::to_string(value).c_str();
 }
 
 template <>
@@ -94,6 +95,12 @@ void web::configLoad::setValue(pugi::xml_node& item, const std::string& value)
     item.append_attribute("value") = value.c_str();
 }
 
+template <>
+void web::configLoad::setValue(pugi::xml_node& item, const std::string_view& value)
+{
+    item.append_attribute("value") = value.data();
+}
+
 template <>
 void web::configLoad::setValue(pugi::xml_node& item, const fs::path& value)
 {
@@ -155,15 +162,16 @@ void web::configLoad::process()
     }
 
     // write all values with simple type (string, int, bool)
-    for (int i = 0; i < int(CFG_MAX); i++) {
-        auto scs = ConfigDefinition::findConfigSetup(config_option_t(i));
-        auto item = values.append_child("item");
-        createItem(item, scs->getItemPath(-1), config_option_t(i), config_option_t(i), scs);
-
+    for (auto&& option : ConfigOptionIterator()) {
         try {
-            log_debug("    Option {:03d} {} = {}", i, scs->getItemPath(), scs->getCurrentValue().c_str());
+            auto scs = ConfigDefinition::findConfigSetup(option);
+            auto item = values.append_child("item");
+            createItem(item, scs->getItemPath(-1), option, option, scs);
+
+            log_debug("    Option {:03d} {} = {}", option, scs->getItemPath(), scs->getCurrentValue().c_str());
             setValue(item, scs->getCurrentValue());
         } catch (const std::runtime_error& e) {
+            log_warning("Option {:03d} {}", option, e.what());
         }
     }
 
@@ -234,6 +242,33 @@ void web::configLoad::process()
         setValue(item, dir->hasSubTitleFile() ? dir->getSubTitleFile() : "");
     }
 
+    // write dynamic content
+    cs = ConfigDefinition::findConfigSetup(CFG_SERVER_DYNAMIC_CONTENT_LIST);
+    auto dynContent = cs->getValue()->getDynamicContentListOption();
+    for (size_t i = 0; i < dynContent->size(); i++) {
+        auto cont = dynContent->get(i);
+
+        auto item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_DYNAMIC_CONTAINER_LOCATION), cs->option, ATTR_DYNAMIC_CONTAINER_LOCATION);
+        setValue(item, cont->getLocation());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_DYNAMIC_CONTAINER_IMAGE), cs->option, ATTR_DYNAMIC_CONTAINER_IMAGE);
+        setValue(item, cont->getImage());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_DYNAMIC_CONTAINER_TITLE), cs->option, ATTR_DYNAMIC_CONTAINER_TITLE);
+        setValue(item, cont->getTitle());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_DYNAMIC_CONTAINER_FILTER), cs->option, ATTR_DYNAMIC_CONTAINER_FILTER);
+        setValue(item, cont->getFilter());
+
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(i, ATTR_DYNAMIC_CONTAINER_SORT), cs->option, ATTR_DYNAMIC_CONTAINER_SORT);
+        setValue(item, cont->getSort());
+    }
+
     // write transconding configuration
     cs = ConfigDefinition::findConfigSetup(CFG_TRANSCODING_PROFILE_LIST);
     auto transcoding = cs->getValue()->getTranscodingProfileListOption();
@@ -261,6 +296,10 @@ void web::configLoad::process()
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_NAME), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_NAME);
         setValue(item, entry->getName());
 
+        item = values.append_child("item");
+        createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_CLIENTFLAGS);
+        setValue(item, ClientConfig::mapFlags(entry->getClientFlags()));
+
         item = values.append_child("item");
         createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_ENABLED);
         setValue(item, entry->getEnabled());
@@ -335,7 +374,7 @@ void web::configLoad::process()
             if (!fourCCList.empty()) {
                 item = values.append_child("item");
                 createItem(item, cs->getItemPath(pr, ATTR_TRANSCODING_PROFILES_PROFLE, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC), cs->option, ATTR_TRANSCODING_PROFILES_PROFLE_AVI4CC_4CC);
-                setValue(item, std::accumulate(std::next(fourCCList.begin()), fourCCList.end(), fourCCList[0], [](auto&& a, auto&& b) { return fmt::format("{}, {}", a.c_str(), b.c_str()); }));
+                setValue(item, std::accumulate(next(fourCCList.begin()), fourCCList.end(), fourCCList[0], [](auto&& a, auto&& b) { return fmt::format("{}, {}", a.c_str(), b.c_str()); }));
             }
         }
         pr++;
@@ -418,9 +457,9 @@ void web::configLoad::process()
         } else {
             auto cs = ConfigDefinition::findConfigSetupByPath(entry.item, true);
             auto acs = ConfigDefinition::findConfigSetupByPath(entry.item, true, cs);
-            if (cs != nullptr) {
+            if (cs) {
                 auto item = values.append_child("item");
-                createItem(item, entry.item, cs->option, acs != nullptr ? acs->option : CFG_MAX);
+                createItem(item, entry.item, cs->option, acs ? acs->option : CFG_MAX);
                 setValue(item, entry.value);
                 item.attribute("status") = entry.status.c_str();
                 item.attribute("origValue") = config->getOrigValue(entry.item).c_str();
