@@ -40,10 +40,7 @@ web::directories::directories(std::shared_ptr<ContentManager> content)
 {
 }
 
-using dirInfo = struct {
-    fs::path filename;
-    bool hasContent;
-};
+using dirInfo = std::pair<fs::path, bool>;
 
 void web::directories::process()
 {
@@ -64,6 +61,7 @@ void web::directories::process()
 
     // don't bother users with system directorties
     auto&& excludes_fullpath = config->getArrayOption(CFG_IMPORT_SYSTEM_DIRECTORIES);
+    auto&& includes_fullpath = config->getArrayOption(CFG_IMPORT_VISIBLE_DIRECTORIES);
     // don't bother users with special or config directorties
     constexpr auto excludes_dirname = std::array {
         "lost+found",
@@ -78,12 +76,17 @@ void web::directories::process()
 
         if (!it.is_directory(ec))
             continue;
-        if (std::find(excludes_fullpath.begin(), excludes_fullpath.end(), filepath) != excludes_fullpath.end())
-            continue;
-        if (std::find(excludes_dirname.begin(), excludes_dirname.end(), filepath.filename()) != excludes_dirname.end()
-            || (exclude_config_dirs && startswith(filepath.filename(), ".")))
-            continue;
-
+        if (!includes_fullpath.empty()
+            && std::none_of(includes_fullpath.begin(), includes_fullpath.end(), //
+                [&](auto&& sub) { return startswith(filepath.string(), sub) || startswith(sub, filepath.string()); }))
+            continue; // skip unwanted dir
+        if (includes_fullpath.empty()) {
+            if (std::find(excludes_fullpath.begin(), excludes_fullpath.end(), filepath) != excludes_fullpath.end())
+                continue; // skip excluded dir
+            if (std::find(excludes_dirname.begin(), excludes_dirname.end(), filepath.filename()) != excludes_dirname.end()
+                || (exclude_config_dirs && startswith(filepath.filename().string(), ".")))
+                continue; // skip dir with leading .
+        }
         auto&& dir = fs::directory_iterator(filepath, ec);
         bool hasContent = std::any_of(begin(dir), end(dir), [&](auto&& sub) { return sub.is_directory(ec) || isRegularFile(sub, ec); });
 
@@ -94,10 +97,11 @@ void web::directories::process()
 
     auto f2i = StringConverter::f2i(config);
     for (auto&& [key, val] : filesMap) {
+        auto&& [file, has] = val;
         auto ce = containers.append_child("container");
         ce.append_attribute("id") = key.c_str();
-        ce.append_attribute("child_count") = val.hasContent;
+        ce.append_attribute("child_count") = has;
 
-        ce.append_attribute("title") = f2i->convert(val.filename).c_str();
+        ce.append_attribute("title") = f2i->convert(file).c_str();
     }
 }
