@@ -46,6 +46,7 @@ web::edit_load::edit_load(std::shared_ptr<ContentManager> content)
 {
 }
 
+/// \brief: process request 'edit_load' to list contents of a folder
 void web::edit_load::process()
 {
     check_request();
@@ -58,10 +59,12 @@ void web::edit_load::process()
     objectID = std::stoi(objID);
     auto obj = database->loadObject(objectID);
 
+    // set handling of json properties
     auto root = xmlDoc->document_element();
     xml2JsonHints->setFieldType("value", "string");
     xml2JsonHints->setFieldType("title", "string");
 
+    // write object core info
     auto item = root.append_child("item");
     item.append_attribute("object_id") = objectID;
 
@@ -83,8 +86,19 @@ void web::edit_load::process()
         lmtEl.append_attribute("editable") = false;
     }
 
+    if (obj->getUTime() > std::chrono::seconds::zero()) {
+        auto lmtEl = item.append_child("last_updated");
+        lmtEl.append_attribute("value") = fmt::format("{:%Y-%m-%d %H:%M:%S}", fmt::localtime(obj->getUTime().count())).c_str();
+        lmtEl.append_attribute("editable") = false;
+    } else {
+        auto lmtEl = item.append_child("last_updated");
+        lmtEl.append_attribute("value") = "";
+        lmtEl.append_attribute("editable") = false;
+    }
+
     item.append_child("obj_type").append_child(pugi::node_pcdata).set_value(CdsObject::mapObjectType(obj->getObjectType()).data());
 
+    // write metadata
     auto metaData = item.append_child("metadata");
     xml2JsonHints->setArrayName(metaData, "metadata");
     xml2JsonHints->setFieldType("metavalue", "string");
@@ -96,6 +110,7 @@ void web::edit_load::process()
         metaEntry.append_attribute("editable") = false;
     }
 
+    // write auxdata
     auto auxData = item.append_child("auxdata");
     xml2JsonHints->setArrayName(auxData, "auxdata");
     xml2JsonHints->setFieldType("auxvalue", "string");
@@ -111,42 +126,63 @@ void web::edit_load::process()
     xml2JsonHints->setArrayName(resources, "resources");
     xml2JsonHints->setFieldType("resvalue", "string");
 
-    int resIndex = 0;
+    auto objItem = std::dynamic_pointer_cast<CdsItem>(obj);
+
+    // write resource info
     for (auto&& resItem : obj->getResources()) {
         auto resEntry = resources.append_child("resources");
         resEntry.append_attribute("resname") = "----RESOURCE----";
-        resEntry.append_attribute("resvalue") = fmt::format("{}", resIndex).c_str();
+        resEntry.append_attribute("resvalue") = fmt::to_string(resItem->getResId()).c_str();
         resEntry.append_attribute("editable") = false;
 
         resEntry = resources.append_child("resources");
         resEntry.append_attribute("resname") = "handlerType";
-        resEntry.append_attribute("resvalue") = fmt::format("{}", MetadataHandler::mapContentHandler2String(resItem->getHandlerType())).c_str();
+        resEntry.append_attribute("resvalue") = fmt::to_string(MetadataHandler::mapContentHandler2String(resItem->getHandlerType())).c_str();
         resEntry.append_attribute("editable") = false;
 
+        // write resource content
+        if (objItem) {
+            std::string url = UpnpXMLBuilder::renderOneResource(server->getVirtualUrl(), objItem, resItem);
+            if (resItem->isMetaResource(ID3_ALBUM_ART) //
+                || (resItem->getHandlerType() == CH_LIBEXIF && resItem->getParameter(RESOURCE_CONTENT_TYPE) == EXIF_THUMBNAIL) //
+                || (resItem->getHandlerType() == CH_FFTH && resItem->getOption(RESOURCE_CONTENT_TYPE) == THUMBNAIL)) {
+                auto image = resources.append_child("resources");
+                image.append_attribute("resname") = "image";
+                image.append_attribute("resvalue") = url.c_str();
+                image.append_attribute("editable") = false;
+            } else {
+                resEntry = resources.append_child("resources");
+                resEntry.append_attribute("resname") = "link";
+                resEntry.append_attribute("resvalue") = url.c_str();
+                resEntry.append_attribute("editable") = false;
+            }
+        }
+
+        // write resource parameters
         for (auto&& [key, val] : resItem->getParameters()) {
             auto resEntry = resources.append_child("resources");
             resEntry.append_attribute("resname") = fmt::format(".{}", key.c_str()).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
+        // write resource attributes
         for (auto&& [key, val] : resItem->getAttributes()) {
             auto resEntry = resources.append_child("resources");
             resEntry.append_attribute("resname") = fmt::format(" {}", key.c_str()).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
+        // write resource options
         for (auto&& [key, val] : resItem->getOptions()) {
             auto resEntry = resources.append_child("resources");
             resEntry.append_attribute("resname") = fmt::format("-{}", key.c_str()).c_str();
             resEntry.append_attribute("resvalue") = val.c_str();
             resEntry.append_attribute("editable") = false;
         }
-        resIndex++;
     }
 
+    // write item meta info
     if (obj->isItem()) {
-        auto objItem = std::static_pointer_cast<CdsItem>(obj);
-
         auto description = item.append_child("description");
         description.append_attribute("value") = objItem->getMetadata(M_DESCRIPTION).c_str();
         description.append_attribute("editable") = true;
@@ -159,8 +195,8 @@ void web::edit_load::process()
         mimeType.append_attribute("value") = objItem->getMimeType().c_str();
         mimeType.append_attribute("editable") = true;
 
-        std::string url;
-        if (UpnpXMLBuilder::renderItemImage(server->getVirtualUrl(), objItem, url)) {
+        auto [url, artAdded] = UpnpXMLBuilder::renderItemImage(server->getVirtualUrl(), objItem);
+        if (artAdded) {
             auto image = item.append_child("image");
             image.append_attribute("value") = url.c_str();
             image.append_attribute("editable") = false;
@@ -173,10 +209,11 @@ void web::edit_load::process()
         }
     }
 
+    // write container meta info
     if (obj->isContainer()) {
         auto cont = std::static_pointer_cast<CdsContainer>(obj);
-        std::string url;
-        if (UpnpXMLBuilder::renderContainerImage(server->getVirtualUrl(), cont, url)) {
+        auto [url, artAdded] = UpnpXMLBuilder::renderContainerImage(server->getVirtualUrl(), cont);
+        if (artAdded) {
             auto image = item.append_child("image");
             image.append_attribute("value") = url.c_str();
             image.append_attribute("editable") = false;
