@@ -50,7 +50,7 @@ class SessionManager;
 /// \brief Authentication handler (used over AJAX)
 class auth : public WebRequestHandler {
 protected:
-    std::chrono::seconds timeout;
+    std::chrono::seconds timeout {};
 
 public:
     explicit auth(std::shared_ptr<ContentManager> content);
@@ -121,8 +121,8 @@ public:
 
 protected:
     void addContainer(int parentID);
-    std::shared_ptr<CdsObject> addItem(int parentID, std::shared_ptr<CdsItem> item);
-    std::shared_ptr<CdsObject> addUrl(int parentID, std::shared_ptr<CdsItemExternalURL> item, bool addProtocol);
+    std::shared_ptr<CdsObject> addItem(int parentID, const std::shared_ptr<CdsItem>& item);
+    std::shared_ptr<CdsObject> addUrl(int parentID, const std::shared_ptr<CdsItemExternalURL>& item, bool addProtocol);
 };
 
 /// \brief autoscan add and remove
@@ -164,7 +164,7 @@ public:
 /// \return the appropriate request handler.
 std::unique_ptr<WebRequestHandler> createWebRequestHandler(
     std::shared_ptr<ContentManager> content,
-    const std::string& page);
+    std::string_view page);
 
 /// \brief Browse clients list
 class clients : public WebRequestHandler {
