@@ -22,6 +22,7 @@
 
 #include <gtest/gtest.h>
 #include <iostream>
+#include <regex>
 
 #include "config/config_manager.h"
 #include "database/search_handler.h"
@@ -35,7 +36,7 @@ decltype(auto) getAllTokens(const std::string& input)
     bool gotToken = false;
     do {
         searchToken = lexer.nextToken();
-        gotToken = searchToken != nullptr;
+        gotToken = !!searchToken;
         if (searchToken)
             searchTokens->push_back(std::move(searchToken));
     } while (gotToken);
@@ -46,7 +47,11 @@ enum class TestCol {
     id = 0,
     item_id,
     property_name,
-    property_value
+    property_value,
+    upnp_class,
+    ref_id,
+    last7,
+    last_updated,
 };
 
 const std::map<TestCol, std::pair<std::string, std::string>> testColMap = {
@@ -54,13 +59,19 @@ const std::map<TestCol, std::pair<std::string, std::string>> testColMap = {
     { TestCol::item_id, { "t", "item_id" } },
     { TestCol::property_name, { "t", "property_name" } },
     { TestCol::property_value, { "t", "property_value" } },
+    { TestCol::upnp_class, { "t", "upnp_class" } },
+    { TestCol::ref_id, { "t", "ref_id" } },
+    { TestCol::last_updated, { "t", "last_updated" } },
 };
 
 const std::vector<std::pair<std::string, TestCol>> testSortMap = {
     { "id", TestCol::id },
-    { "item", TestCol::item_id },
-    { "name", TestCol::property_name },
-    { "val", TestCol::property_value },
+    { UPNP_SEARCH_ID, TestCol::item_id },
+    { META_NAME, TestCol::property_name },
+    { META_VALUE, TestCol::property_value },
+    { UPNP_SEARCH_CLASS, TestCol::upnp_class },
+    { UPNP_SEARCH_REFID, TestCol::ref_id },
+    { UPNP_SEARCH_LAST_UPDATED, TestCol::last_updated },
 };
 
 ::testing::AssertionResult executeSearchLexerTest(const std::string& input,
@@ -86,16 +97,16 @@ const std::vector<std::pair<std::string, TestCol>> testSortMap = {
 }
 
 ::testing::AssertionResult executeSearchParserTest(const SQLEmitter& emitter, const std::string& input,
-    const std::string expectedOutput)
+    const std::string& expectedOutput, const std::string& expectedRe = "")
 {
     try {
         auto parser = SearchParser(emitter, input);
         auto rootNode = parser.parse();
-        if (rootNode == nullptr)
+        if (!rootNode)
             return ::testing::AssertionFailure() << "Failed to create AST";
 
         auto output = rootNode->emit();
-        if (output != expectedOutput)
+        if (output != expectedOutput && !std::regex_match(output, std::regex(expectedRe, std::regex::ECMAScript)))
             return ::testing::AssertionFailure() << "\nExpected [" << expectedOutput << "]\nActual   [" << output << "]\n";
 
         return ::testing::AssertionSuccess();
@@ -105,10 +116,10 @@ const std::vector<std::pair<std::string, TestCol>> testSortMap = {
 }
 
 ::testing::AssertionResult executeSortParserTest(const std::string& input,
-    const std::string expectedOutput)
+    const std::string& expectedOutput)
 {
     try {
-        auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', testSortMap, testColMap);
+        auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
         auto parser = SortParser(columnMapper, input);
         auto output = parser.parse();
         if (output.empty())
@@ -243,7 +254,7 @@ TEST(SearchLexer, MultipleTokens)
     };
     EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
 
-    input = "dc:creator = \"some band with \\\"a double-quote\"";
+    input = R"(dc:creator = "some band with \"a double-quote")";
     expectedTokens = {
         { "dc:creator", TokenType::PROPERTY },
         { "=", TokenType::COMPAREOP },
@@ -253,7 +264,7 @@ TEST(SearchLexer, MultipleTokens)
     };
     EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
 
-    input = "dc:creator = \"some band with \\\"a double-quote\\\"\"";
+    input = R"(dc:creator = "some band with \"a double-quote\"")";
     expectedTokens = {
         { "dc:creator", TokenType::PROPERTY },
         { "=", TokenType::COMPAREOP },
@@ -263,7 +274,7 @@ TEST(SearchLexer, MultipleTokens)
     };
     EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
 
-    input = "upnp:class derivedfrom \"object.item.audioItem\" and upnp:artist=\"King Krule\"";
+    input = R"(upnp:class derivedfrom "object.item.audioItem" and upnp:artist="King Krule")";
     expectedTokens = {
         { "upnp:class", TokenType::PROPERTY },
         { "derivedfrom", TokenType::STRINGOP },
@@ -279,7 +290,7 @@ TEST(SearchLexer, MultipleTokens)
     };
     EXPECT_TRUE(executeSearchLexerTest(input, expectedTokens));
 
-    input = "upnp:class derivedfrom \"object.item.audioItem\" and (upnp:artist=\"King Krule\" or dc:title=\"Heartattack and Vine\")";
+    input = R"(upnp:class derivedfrom "object.item.audioItem" and (upnp:artist="King Krule" or dc:title="Heartattack and Vine"))";
     expectedTokens = {
         { "upnp:class", TokenType::PROPERTY },
         { "derivedfrom", TokenType::STRINGOP },
@@ -306,143 +317,168 @@ TEST(SearchLexer, MultipleTokens)
 
 TEST(SearchParser, SimpleSearchCriteriaUsingEqualsOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "dc:title=\"Hospital Roll Call\"",
-        "(m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL)"));
+        "(_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\"",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL)"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // equalsOpExpr or equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\" or dc:title=\"Hospital Roll Call\"",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL)"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // equalsOpExpr or equalsOpExpr or equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\" or dc:title=\"Hospital Roll Call\" or upnp:artist=\"Deafheaven\"",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL)"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaUsingEqualsOperatorParenthesesForSqlite)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // (equalsOpExpr)
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "(upnp:album=\"Scraps At Midnight\")",
-        "((m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL))"));
+        "((_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // (equalsOpExpr or equalsOpExpr)
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "(upnp:album=\"Scraps At Midnight\" or dc:title=\"Hospital Roll Call\")",
-        "((m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL))"));
+        "((_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // (equalsOpExpr or equalsOpExpr) or equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "(upnp:album=\"Scraps At Midnight\" or dc:title=\"Hospital Roll Call\") or upnp:artist=\"Deafheaven\"",
-        "((m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL)) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL)"));
+        "((_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL)) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // equalsOpExpr or (equalsOpExpr or equalsOpExpr)
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\" or (dc:title=\"Hospital Roll Call\" or upnp:artist=\"Deafheaven\")",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) OR ((m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL))"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) OR ((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // equalsOpExpr and (equalsOpExpr or equalsOpExpr)
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\" and (dc:title=\"Hospital Roll Call\" or upnp:artist=\"Deafheaven\")",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) AND ((m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL))"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) AND ((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // equalsOpExpr and (equalsOpExpr or equalsOpExpr or equalsOpExpr)
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "upnp:album=\"Scraps At Midnight\" and (dc:title=\"Hospital Roll Call\" or upnp:artist=\"Deafheaven\" or upnp:artist=\"Pavement\")",
-        "(m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Scraps At Midnight') AND c.upnp_class IS NOT NULL) AND ((m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Pavement') AND c.upnp_class IS NOT NULL))"));
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Scraps At Midnight') AND _t_._upnp_class_ IS NOT NULL) AND ((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Pavement') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // (equalsOpExpr or equalsOpExpr or equalsOpExpr) and equalsOpExpr and equalsOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter,
         "(dc:title=\"Hospital Roll Call\" or upnp:artist=\"Deafheaven\" or upnp:artist=\"Pavement\") and upnp:album=\"Nevermind\" and upnp:album=\"Sunbather\"",
-        "((m.property_name='dc:title' AND LOWER(m.property_value)=LOWER('Hospital Roll Call') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Deafheaven') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value)=LOWER('Pavement') AND c.upnp_class IS NOT NULL)) AND (m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Nevermind') AND c.upnp_class IS NOT NULL) AND (m.property_name='upnp:album' AND LOWER(m.property_value)=LOWER('Sunbather') AND c.upnp_class IS NOT NULL)"));
+        "((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_)=LOWER('Hospital Roll Call') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Deafheaven') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_)=LOWER('Pavement') AND _t_._upnp_class_ IS NOT NULL)) AND (_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Nevermind') AND _t_._upnp_class_ IS NOT NULL) AND (_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_)=LOWER('Sunbather') AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaUsingContainsOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // (containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album contains \"Midnight\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) LIKE LOWER('%Midnight%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album contains \"Midnight\"", "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) LIKE LOWER('%Midnight%') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album contains \"Midnight\" OR upnp:artist contains \"HEAVE\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) LIKE LOWER('%Midnight%') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value) LIKE LOWER('%HEAVE%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album contains \"Midnight\" OR upnp:artist contains \"HEAVE\"", 
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) LIKE LOWER('%Midnight%') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_) LIKE LOWER('%HEAVE%') AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaUsingDoesNotContainOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // (containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album doesnotcontain \"Midnight\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) NOT LIKE LOWER('%Midnight%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album doesnotcontain \"Midnight\"",
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) NOT LIKE LOWER('%Midnight%') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album doesNotContain \"Midnight\" or upnp:artist doesnotcontain \"HEAVE\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) NOT LIKE LOWER('%Midnight%') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value) NOT LIKE LOWER('%HEAVE%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album doesNotContain \"Midnight\" or upnp:artist doesnotcontain \"HEAVE\"",
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) NOT LIKE LOWER('%Midnight%') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_) NOT LIKE LOWER('%HEAVE%') AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaUsingStartsWithOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // (containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album startswith \"Midnight\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) LIKE LOWER('Midnight%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album startswith \"Midnight\"", "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) LIKE LOWER('Midnight%') AND _t_._upnp_class_ IS NOT NULL)"));
 
     // (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album startsWith \"Midnight\" or upnp:artist startswith \"HEAVE\"", "(m.property_name='upnp:album' AND LOWER(m.property_value) LIKE LOWER('Midnight%') AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND LOWER(m.property_value) LIKE LOWER('HEAVE%') AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album startsWith \"Midnight\" or upnp:artist startswith \"HEAVE\"",
+        "(_t_._property_name_='upnp:album' AND LOWER(_t_._property_value_) LIKE LOWER('Midnight%') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND LOWER(_t_._property_value_) LIKE LOWER('HEAVE%') AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaUsingExistsOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // (containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album exists true", "(m.property_name='upnp:album' AND m.property_value IS NOT NULL AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album exists true",
+        "(_t_._property_name_='upnp:album' AND _t_._property_value_ IS NOT NULL AND _t_._upnp_class_ IS NOT NULL)"));
 
     // (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album exists true or upnp:artist exists false", "(m.property_name='upnp:album' AND m.property_value IS NOT NULL AND c.upnp_class IS NOT NULL) OR (m.property_name='upnp:artist' AND m.property_value IS NULL AND c.upnp_class IS NOT NULL)"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:album exists true or upnp:artist exists false",
+        "(_t_._property_name_='upnp:album' AND _t_._property_value_ IS NOT NULL AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='upnp:artist' AND _t_._property_value_ IS NULL AND _t_._upnp_class_ IS NOT NULL)"));
 }
 
 TEST(SearchParser, SearchCriteriaWithExtendsOperator)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // derivedfromOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedfrom \"object.item.audioItem\"",
-        "(LOWER(c.upnp_class) LIKE LOWER('object.item.audioItem%'))"));
+        "(LOWER(_t_._upnp_class_) LIKE LOWER('object.item.audioItem%'))"));
 
     // derivedfromOpExpr and (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedfrom \"object.item.audioItem\" and (dc:title contains \"britain\" or dc:creator contains \"britain\"", "(LOWER(c.upnp_class) LIKE LOWER('object.item.audioItem%')) AND ((m.property_name='dc:title' AND LOWER(m.property_value) LIKE LOWER('%britain%') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:creator' AND LOWER(m.property_value) LIKE LOWER('%britain%') AND c.upnp_class IS NOT NULL))"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedfrom \"object.item.audioItem\" and (dc:title contains \"britain\" or dc:creator contains \"britain\"",
+        "(LOWER(_t_._upnp_class_) LIKE LOWER('object.item.audioItem%')) AND ((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_) LIKE LOWER('%britain%') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:creator' AND LOWER(_t_._property_value_) LIKE LOWER('%britain%') AND _t_._upnp_class_ IS NOT NULL))"));
 
     // derivedFromOpExpr and (containsOpExpr or containsOpExpr)
-    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedFrom \"object.item.audioItem\" and (dc:title contains \"britain\" or dc:creator contains \"britain\"", "(LOWER(c.upnp_class) LIKE LOWER('object.item.audioItem%')) AND ((m.property_name='dc:title' AND LOWER(m.property_value) LIKE LOWER('%britain%') AND c.upnp_class IS NOT NULL) OR (m.property_name='dc:creator' AND LOWER(m.property_value) LIKE LOWER('%britain%') AND c.upnp_class IS NOT NULL))"));
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedFrom \"object.item.audioItem\" and (dc:title contains \"britain\" or dc:creator contains \"britain\"",
+        "(LOWER(_t_._upnp_class_) LIKE LOWER('object.item.audioItem%')) AND ((_t_._property_name_='dc:title' AND LOWER(_t_._property_value_) LIKE LOWER('%britain%') AND _t_._upnp_class_ IS NOT NULL) OR (_t_._property_name_='dc:creator' AND LOWER(_t_._property_value_) LIKE LOWER('%britain%') AND _t_._upnp_class_ IS NOT NULL))"));
 }
 
 TEST(SearchParser, SearchCriteriaWindowMedia)
 {
-    DefaultSQLEmitter sqlEmitter("", "c", "m");
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
     // derivedfromOpExpr
     EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedfrom \"object.item.videoItem\" and @refID exists false",
-        "(LOWER(c.upnp_class) LIKE LOWER('object.item.videoItem%')) AND (c.ref_id IS NULL)"));
+        "(LOWER(_t_._upnp_class_) LIKE LOWER('object.item.videoItem%')) AND (_t_._ref_id_ IS NULL)"));
+}
+
+TEST(SearchParser, SearchCriteriaDynamic)
+{
+    auto columnMapper = std::make_shared<EnumColumnMapper<TestCol>>('_', '_', "t", "TestTable", testSortMap, testColMap);
+    DefaultSQLEmitter sqlEmitter(columnMapper, columnMapper, columnMapper);
+    EXPECT_TRUE(executeSearchParserTest(sqlEmitter, "upnp:class derivedfrom \"object.item\" and last_updated > \"@last7\"",
+        "(LOWER(_t_._upnp_class_) LIKE LOWER('object.item%')) AND (_t_._last_updated_ > [0-9]+))", 
+        R"(\(LOWER\(_t_\._upnp_class_\) LIKE LOWER\('object\.item%'\)\) AND \(_t_\._last_updated_ > [0-9]+\))")); // regular expression because last7 is dynamic
 }
 
 TEST(SortParser, SortCriteria)
 {
-    EXPECT_TRUE(executeSortParserTest("+id,-name,+val",
+    EXPECT_TRUE(executeSortParserTest("+id,-name,+value",
         "_t_._id_ ASC, _t_._property_name_ DESC, _t_._property_value_ ASC"));
 }
 
 TEST(SortParser, SortCriteriaNoDir)
 {
-    EXPECT_TRUE(executeSortParserTest("+id,name,+val",
+    EXPECT_TRUE(executeSortParserTest("+id,name,+value",
         "_t_._id_ ASC, _t_._property_name_ ASC, _t_._property_value_ ASC"));
 }
 
 TEST(SortParser, SortCriteriaError)
 {
-    EXPECT_TRUE(executeSortParserTest("+id,nme,+val",
+    EXPECT_TRUE(executeSortParserTest("+id,nme,+value",
         "_t_._id_ ASC, _t_._property_value_ ASC"));
 }
