@@ -2,9 +2,9 @@
 
 Gerbera - https://gerbera.io/
 
-    my_sql_config_fake.h - this file is part of Gerbera.
+    mysql_config_fake.h - this file is part of Gerbera.
 
-    Copyright (C) 2020 Gerbera Contributors
+    Copyright (C) 2020-2021 Gerbera Contributors
 
     Gerbera is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License version 2
@@ -34,6 +34,15 @@ public:
         if (option == CFG_SERVER_STORAGE_MYSQL_USERNAME) {
             return "root";
         }
+        if (option == CFG_SERVER_STORAGE_DRIVER) {
+            return "mysql";
+        }
+        if (option == CFG_SERVER_STORAGE_MYSQL_INIT_SQL_FILE) {
+            return "mysql.sql";
+        }
+        if (option == CFG_SERVER_STORAGE_MYSQL_UPGRADE_FILE) {
+            return "mysql-upgrade.xml";
+        }
 //        if (option == CFG_SERVER_STORAGE_MYSQL_DATABASE) {
 //            return "gerbera";
 //        }
@@ -54,6 +63,8 @@ public:
     void setOrigValue(const std::string& item, int value) override { }
     bool hasOrigValue(const std::string& item) const override { return false; }
     std::shared_ptr<TranscodingProfileList> getTranscodingProfileListOption(config_option_t option) const override { return nullptr; }
+    std::shared_ptr<DynamicContentList> getDynamicContentListOption(config_option_t option) const override { return nullptr; }
+    fs::path getDataDir() const override { return "/usr/local/share/gerbera"; }
 };
 
 #endif //GERBERA_MYSQL_CONFIG_FAKE_H
