@@ -28,11 +28,11 @@ public:
 
     InternalUrlM3UPlaylistTest()
     {
-        commonScriptMock.reset(new ::testing::NiceMock<CommonScriptMock>());
+        commonScriptMock = std::make_unique<::testing::NiceMock<CommonScriptMock>>();
         scriptName = "playlists.js";
     };
 
-    virtual ~InternalUrlM3UPlaylistTest()
+    ~InternalUrlM3UPlaylistTest() override
     {
         commonScriptMock.reset();
     };
