@@ -27,21 +27,21 @@
 class RuntimeTest : public ::testing::Test {
 protected:
     // You can do set-up work for each test here.
-    inline RuntimeTest() {};
+    inline RuntimeTest() = default;
 
     // You can do clean-up work that doesn't throw exceptions here.
-    inline virtual ~RuntimeTest() {};
+    inline ~RuntimeTest() override = default;
 
     // If the constructor and destructor are not enough for setting up
     // and cleaning up each test, you can define the following methods:
 
     // Code here will be called immediately after the constructor (right
     // before each test).
-    inline virtual void SetUp() {};
+    inline void SetUp() override {};
 
     // Code here will be called immediately after each test (right
     // before the destructor).
-    inline virtual void TearDown() {};
+    inline void TearDown() override {};
 };
 
 #endif // __RUNTIME_TEST_H__
