@@ -208,8 +208,10 @@ $.widget('grb.config', {
         let childValue = listValue.parentItem.childList[child];
         if (childValue &&  childValue.length > 0) {
           childValue.forEach((j) => {
-            j.status = listValue.status;
-            this.options.addResultItem(j);
+            if (!j.item || j.item.startsWith(listValue.item)) {
+                j.status = listValue.status;
+                this.options.addResultItem(j);
+            }
           });
         }
       });
@@ -247,6 +249,7 @@ $.widget('grb.config', {
 
   createSection: function (list, xpath, section, values, level, parentItem, status = 'unchanged') {
     parentItem.childList = {};
+    parentItem.subList = [];
     parentItem.childList[0] = [];
 
     this.meta.forEach((m) => {
@@ -346,12 +349,12 @@ $.widget('grb.config', {
           let lineStatus = status;
 
           if (xpath && xpath.length > 0) {
-            const itemId = "item_" + xpath.replace(RegExp('/','g'), "_") + "_" + count
+            const itemId = "item_" + xpath.replace(RegExp('/','g'), "_") + "_" + count;
             let xpathList = list.find("#" + itemId);
             if (xpathList === null || xpathList.length === 0) {
               line = $('<li></li>');
               line.attr('style', 'padding-top: 20px');
-              line.attr('id', "line_" + item.item.replace("RegExp('/','g')","_"));
+              line.attr('id', "line_" + item.item.replace(RegExp('/','g'),"_"));
               list.removeClass('fa-ul');
               list.addClass('fa-ul');
               let symbol = $('<span></span>').addClass('fa-li');
@@ -367,7 +370,7 @@ $.widget('grb.config', {
                 parentItem: parentItem,
                 editable: parentItem.editable};
               parentItem.childList[count] = [];
-              values.filter((v) => { return v.item == listValue.item; }).forEach((v) => {
+              values.filter((v) => { return v.item === listValue.item || v.item === listValue.item + item.item.replace(xpath,''); }).forEach((v) => {
                 listValue.status = v.status;
                 listValue.id = v.id;
               });
@@ -383,13 +386,14 @@ $.widget('grb.config', {
                 }
                 listValue.editor.addClass(listValue.status);
                 listValue.removeItemClicked = function(event) {
-                  listValue.target.removeItemClicked (listValue, event);
-                }
+                  listValue.target.removeItemClicked(listValue, event);
+                };
                 symbol.off('click').on('click', listValue.removeItemClicked);
               } else {
                 icon.removeClass('fa-ban');
                 icon.addClass('fa-circle');
               }
+              parentItem.subList[count] = listValue;
               //let text = $('<span></span>');
               //text.text(count).appendTo(line);
               //text.attr('title', item.item);
@@ -431,12 +435,13 @@ $.widget('grb.config', {
           });
           parentItem.childList[count].push(itemValue);
           itemValue.status = lineStatus;
+          itemValue.parentItem = parentItem;
           itemLine.addClass(itemValue.status);
 
           if(item.editable) {
             itemValue.setEntryChanged = function (event) {
               itemValue.target.setEntryChanged(itemValue, event);
-            }
+            };
             itemValue.target = this;
             itemValue.config = item;
             itemValue.editor = input;
@@ -506,20 +511,43 @@ $.widget('grb.config', {
             const icon = $('<i></i>', {"class": "fa " + "fa-undo" });
             link.append(icon);
             if (itemValue.origValue !== '') {
-                link.append(` reset to ${itemValue.origValue}`);
+              link.append(` reset to ${itemValue.origValue}`);
             } else {
-                link.append(' reset');
+              link.append(' reset');
             }
-            itemValue.resetEntry = function (event) { itemValue.target.resetEntry(itemValue, event); }
+            if (itemValue.defaultValue && itemValue.defaultValue !== '') {
+              link.append(` default value is "${itemValue.defaultValue}"`);
+            }
+            itemValue.resetEntry = function (event) {
+              if (itemValue.parentItem.children.length > 1)
+                itemValue.target.resetEntry(itemValue, event);
+              else
+                itemValue.target.removeItemClicked(itemValue.parentItem.subList[count], event);
+            };
             link.click(itemValue, itemValue.resetEntry);
             link.appendTo(itemLine);
+          } else if (itemValue.source === 'default') {
+            const link = $('<a>', {"title": "copy", "style": "margin-left: 20px"});
+            if (itemValue.defaultValue && itemValue.defaultValue !== '') {
+              link.append(` default value is "${itemValue.defaultValue}"`);
+            } else {
+              link.append(' default value');
+            }
+            link.appendTo(itemLine);
           } else if (itemValue.status !== 'unchanged') {
             const link = $('<a>', {"title": "reset", "style": "margin-left: 20px"});
             if (itemValue.origValue !== '') {
-                link.append(` config.xml value is "${itemValue.origValue}"`);
+              link.append(` config.xml value is "${itemValue.origValue}"`);
             } else {
-                link.append(' no config.xml entry');
+              link.append(' no config.xml entry');
             }
+            if (itemValue.defaultValue && itemValue.defaultValue !== '') {
+              link.append(` default value is "${itemValue.defaultValue}"`);
+            }
+            link.appendTo(itemLine);
+          } else if (itemValue.defaultValue && itemValue.defaultValue !== '') {
+            const link = $('<a>', {"title": "copy", "style": "margin-left: 20px"});
+            link.append(` default value is "${itemValue.defaultValue}"`);
             link.appendTo(itemLine);
           }
         }
@@ -534,7 +562,7 @@ $.widget('grb.config', {
 
   addNewListItemBlock: function (list, item, parentItem, itemCount, xpath, itemId) {
     let lineNew = $('<li></li>');
-    lineNew.attr('id', "line_" + item.item.replace("RegExp('/','g')","_"));
+    lineNew.attr('id', "line_" + item.item.replace(RegExp('/','g'),"_"));
     let textNew = $('<span></span>');
     let symbolNew = $('<span></span>').addClass('fa-li');
     $('<i class="fa"></i>').addClass('fa-plus').appendTo(symbolNew);
@@ -548,7 +576,7 @@ $.widget('grb.config', {
       parentItem: parentItem };
     listValueNew.addItemClicked = function(event) {
       listValueNew.target.addItemClicked (listValueNew, event);
-    }
+    };
     symbolNew.off('click').on('click', listValueNew.addItemClicked);
     textNew.text('Add New Entry').appendTo(lineNew);
     //textNew.attr('title', item.item);
